#if !defined(MATHCW_H)
#define MATHCW_H

/***********************************************************************
This header file provides prototypes and macro definitions for all of
the functions in the Cody/Waite math library, mathcw (cc files -lmcw).
It provides all of the functions defined for <math.h> in both the ISO
C89 and C99 Standards, and several additional ones.  Thus, this file can
be used in place of <math.h>, or in addition to it.

This header file may be used with both C and C++ compilers, and with C++
compilation, all routines are declared with C linkage, so that they can
be called from either C or C++, and will not be subject to the normal
C++ name mangling that encodes argument datatypes in function names.

A C89-compatible compiler is required to handle function prototypes with
argument data types.

C99 introduced a long long data type that older compilers usually do not
support, and six math library functions of that new type.  Thus, the
prototypes of those six functions are protected with a preprocessor
conditional such that either the compiler must define a suitable value
of __STDC_VERSION__ (set to 199901 by C99 compilers, and unset by older
compilers), or else the user must define the symbol HAVE_LONG_LONG_INT.  The
latter is the widely-used standard name generated by GNU
autoconfiguration.

The ISO C++ 1998 and 2003 Standards are both based on C89, and C++
compilers are not expected to set either of the C compiler symbols
__STDC__ or __STDC_VERSION__.  The C++ compiler __cplusplus symbol has
the value 199711L for both 1998 and 2003 Standards.

Nearly 60 of the external names defined by the two C standards are
longer than six characters, but older operating systems to which the
mathcw package has been ported may allow only six or eight characters,
and ignore lettercase.  For those systems, use the standard external
names, but define the symbol HAVE_SHORT_NAMES a compile time to enable
preprocessor substitutions of systematically shortened names from the
implementation namespace (leading underscore + lowercase letter) defined
by Standard C.

If both <math.h> and <mathcw.h> header files are used, the inclusion
order should match the library order, but in reverse:

	#include <mathcw.h>
	#include <math.h>
	cc files -lm -lmcw

	#include <math.h>
	#include <mathcw.h>
	cc files -lmcw -lm

You can reference the symbols __MATHCW_VERSION_STRING__ and
__MATHCW_DATE_STRING__ if you want to record their values in compiled
code.  For example:

	const char * mathcw_version = __MATHCW_VERSION_STRING__;
	const char * mathcw_date = __MATHCW_DATE_STRING__;

The associated symbols __MATHCW_DATE__, __MATHCW_MAJOR_VERSION__,
__MATHCW_MINOR_VERSION__, and __MATHCW_PATCH_VERSION__ have integer values
that may be tested in preprocessor conditionals.

NB: Comments containing an at-delimited word before pointer arguments
are annotations for the splint static lexical analyzer.  The
annotations dramatically reduce the number of false diagnostics from
that useful tool.

***********************************************************************/

#define __MATHCW_DATE__			20060706
#define __MATHCW_DATE_STRING__		"20060706"
#define __MATHCW_MAJOR_VERSION__	1
#define __MATHCW_MINOR_VERSION__	00
#define __MATHCW_PATCH_VERSION__	00
#define __MATHCW_VERSION_STRING__	"1.00.00"

/* These two precisions are now fully supported */
#undef HAVE_LONG_DOUBLE
#undef HAVE_LONG_LONG_DOUBLE
#define HAVE_LONG_DOUBLE		1
#define HAVE_LONG_LONG_DOUBLE		1

#if defined(HAVE_NATIVE_LONG_LONG_DOUBLE)
typedef long long double long_long_double;
#elif defined(HAVE_LONG_DOUBLE)
typedef long double long_long_double;
#else
typedef double long_long_double;
#endif

#include <deccw.h>
#include <inttcw.h>
#include <randcw.h>

#if defined(__cplusplus)
extern "C" {
#endif

#if defined(__COMPILER_KCC__)
#define HAVE_SHORT_NAMES	1
#endif

#if (!defined(HAVE_LONG_LONG_INT)) && ((__STDC_VERSION__ + 0) >= 199901)
#define HAVE_LONG_LONG_INT	1
#endif

#if defined(HAVE_SHORT_NAMES)
#define __STDC_VERSION__	0	/* to eliminate compiler warnings */

#include <shrtcw.h>

#endif /* defined(HAVE_SHORT_NAMES) */

extern int (is_dec_bid)(void);
extern int (is_dec_dpd)(void);

extern int (ilog2)(unsigned int);
extern int (lilog2)(unsigned long int);
extern int (lnlz)(unsigned long int);
extern int (lntz)(unsigned long int);
extern int (lpop)(unsigned long int);
extern int (nlz)(unsigned int);
extern int (ntz)(unsigned int);
extern int (pop)(unsigned int);
extern unsigned int (clp2)(unsigned int);
extern unsigned int (flp2)(unsigned int);
extern unsigned long int (lclp2)(unsigned long int);
extern unsigned long int (lflp2)(unsigned long int);

#if defined(HAVE_LONG_LONG_INT)
extern int (llilog2)(unsigned long long int);
extern int (llnlz)(unsigned long long int);
extern int (llntz)(unsigned long long int);
extern int (llpop)(unsigned long long int);
extern unsigned long long int (llclp2)(unsigned long long int);
extern unsigned long long int (llflp2)(unsigned long long int);
#endif

extern int * (_signgam)(void);
#define signgam (*_signgam())

extern float (acosdegf)(float);
extern float (acosf)(float);
extern float (acoshf)(float);
extern float (acospf)(float);
extern float (acospif)(float);
extern float (adxf)(float, int);
extern float (agmf)(float, float);
extern float (annuityf)(float, float);
extern float (asindegf)(float);
extern float (asinf)(float);
extern float (asinhf)(float);
extern float (asinpf)(float);
extern float (asinpif)(float);
extern float (atan2degf)(float, float);
extern float (atan2f)(float, float);
extern float (atan2pf)(float, float);
extern float (atan2pif)(float, float);
extern float (atandegf)(float);
extern float (atanf)(float);
extern float (atanhf)(float);
extern float (atanpf)(float);
extern float (atanpif)(float);
extern float (bernumf)(int);
extern float (betaf)(float);
extern float (betam1f)(float);
extern float (betnm1f)(int);
extern float (betnumf)(int);
extern float (bi0f)(float);
extern float (bis0f)(float);
extern float (bi1f)(float);
extern float (bis1f)(float);
extern float (binf)(int, float);
extern float (binomf)(int, int);
extern float (bisnf)(int, float);
extern float (bk0f)(float);
extern float (bks0f)(float);
extern float (bk1f)(float);
extern float (bks1f)(float);
extern float (bknf)(int, float);
extern float (bksnf)(int, float);
extern float (cbrtf)(float);
extern float (ceilf)(float);
extern float (chisqf)(int, float);
extern float (compoundf)(float, float);
extern float (copysignf)(float, float);
extern float (cosdegf)(float);
extern float (cosf)(float);
extern float (coshf)(float);
extern float (cospf)(float);
extern float (cospif)(float);
extern float (cotandegf)(float);
extern float (cotanf)(float);
extern float (cotanpf)(float);
extern float (cotanpif)(float);
extern float (dfactf)(int);
extern float (echebf)(float, int, const float []);
extern float (eljaamf)(float, float);
extern float (eljacdf)(float, float);
extern float (eljacnf)(float, float);
extern float (eljacsf)(float, float);
extern float (eljadcf)(float, float);
extern float (eljadnf)(float, float);
extern float (eljadsf)(float, float);
extern float (eljagf)(float, float, int, /*@out@*/ float *, /*@out@*/ float *, /*@out@*/ float *, /*@out@*/ float *, /*@out@*/ int *);
extern float (eljamf)(float, float);
extern float (eljancf)(float, float);
extern float (eljandf)(float, float);
extern float (eljansf)(float, float);
extern float (eljascf)(float, float);
extern float (eljasdf)(float, float);
extern float (eljasnf)(float, float);
extern float (eljcdf)(float, float);
extern float (eljcnf)(float, float);
extern float (eljcsf)(float, float);
extern float (eljdcf)(float, float);
extern float (eljdnf)(float, float);
extern float (eljdsf)(float, float);
extern float (eljhf)(float, float);
extern void (eljh4f)(/*@out@*/ float[], float, float);
extern float (eljncf)(float, float);
extern float (eljndf)(float, float);
extern float (eljnsf)(float, float);
extern float (eljscf)(float, float);
extern float (eljsdf)(float, float);
extern float (eljsnf)(float, float);
extern float (eljtf)(float, float);
extern float (eljt1f)(float, float);
extern float (eljt2f)(float, float);
extern float (eljt3f)(float, float);
extern float (eljt4f)(float, float);
extern void (eljtaf)(/*@out@*/ float[], float, float);
extern float (eljtd1f)(float, float);
extern float (eljtd2f)(float, float);
extern float (eljtd3f)(float, float);
extern float (eljtd4f)(float, float);
extern void (eljtdaf)(/*@out@*/ float [], float, float);
extern float (eljzf)(float, float);
extern float (elkf)(float);
extern float (elkm1f)(float);
extern float (elldif)(float, float);
extern float (ellecf)(float);
extern float (ellef)(float);
extern float (elleif)(float, float);
extern float (ellfif)(float, float);
extern float (ellkcf)(float);
extern float (ellkf)(float);
extern float (ellknf)(float);
extern float (ellpif)(float, float, float);
extern float (ellrcf)(float, float);
extern float (ellrdf)(float, float, float);
extern float (ellref)(float, float);
extern float (ellrff)(float, float, float);
extern float (ellrgf)(float, float, float);
extern float (ellrhf)(float, float, float, float);
extern float (ellrjf)(float, float, float, float);
extern float (ellrkf)(float, float);
extern float (ellrlf)(float, float, float);
extern float (ellrmf)(float, float, float);
extern float (elntcf)(float, float);
extern float (elntdf)(float, float);
extern float (elntnf)(float, float);
extern float (elntsf)(float, float);
extern float (elqf)(float);
extern float (elq1pf)(float);
extern float (elqcf)(float);
extern float (elqc1pf)(float);
extern float (elwdpf)(float, float, float);
extern void (elwef)(/*@null@*/ /*@out@*/ float *, /*@null@*/ /*@out@*/ float *, float, float);
extern void (elwgf)(/*@null@*/ /*@out@*/ float *, /*@null@*/ /*@out@*/ float *, float, float);
extern float (elwipf)(float, float, float);
extern void (elwkf)(/*@null@*/ /*@out@*/ float *, /*@null@*/ /*@out@*/ float *, float, float);
extern void (elwof)(/*@null@*/ /*@out@*/ float *, /*@null@*/ /*@out@*/ float *, float, float);
extern float (elwpf)(float, float, float);
extern float (elwsf)(float, float, float);
extern float (elwzf)(float, float, float);
extern float (ereducef)(float, float, int, const float [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ float *, int);
extern float (erfcf)(float);
extern float (erff)(float);
extern float (eriducef)(float, float, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ float *, int);
extern float (eulnumf)(int);
extern float (exp10f)(float);
extern float (exp10m1f)(float);
extern float (exp16f)(float);
extern float (exp16m1f)(float);
extern float (exp2f)(float);
extern float (exp2m1f)(float);
extern float (exp8f)(float);
extern float (exp8m1f)(float);
extern float (expf)(float);
extern float (expm1f)(float);
extern float (fabsf)(float);
extern float (factf)(int);
extern float (fdimf)(float, float);
extern float (fibnumf)(int);
extern float (floorf)(float);
extern float (fmaf)(float, float, float);
extern float (fmaxf)(float, float);
extern float (fminf)(float, float);
extern float (fmodf)(float, float);
extern void (fmulf)(/*@out@*/ float [/* 2 */], float, float);
extern int (fpclassifyf)(float);
extern float (frexpf)(float, /*@out@*/ int *);
extern float (frexphf)(float, /*@out@*/ int *);
extern float (frexpof)(float, /*@out@*/ int *);
extern void (gamibf)(/*@out@*/ float [/* 2 */], float, float);
extern float (gamicf)(float, float);
extern float (gamif)(float, float);
extern float (hypotf)(float, float);
extern float (ichisqf)(int, float);
extern float (ierfcf)(float);
extern float (ierff)(float);
extern int (ilogbf)(float);
extern float (inftyf)(void);
extern int (intxpf)(float);
extern float (iphicf)(float);
extern float (iphif)(float);
extern float (ipowf)(float, int);
extern int (isfinitef)(float);
extern int (isgreaterequalf)(float, float);
extern int (isgreaterf)(float, float);
extern int (isinff)(float);
extern int (islessequalf)(float, float);
extern int (islessf)(float, float);
extern int (islessgreaterf)(float, float);
extern int (isnanf)(float);
extern int (isnormalf)(float);
extern int (isqnanf)(float);
extern int (issnanf)(float);
extern int (issubnormalf)(float);
extern int (isunorderedf)(float, float);
extern float (j0f)(float);
extern float (j1f)(float);
extern float (jnf)(int, float);
extern float (ldexpf)(float, int);
extern float (ldexphf)(float, int);
extern float (ldexpof)(float, int);
extern float (lgammaf)(float);
extern float (lgammaf_r)(float, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintf)(float);
extern long long int (llroundf)(float);
#endif

extern float (log101pf)(float);
extern float (log10f)(float);
extern float (log161pf)(float);
extern float (log16f)(float);
extern float (log1pf)(float);
extern float (log21pf)(float);
extern float (log2f)(float);
extern float (log81pf)(float);
extern float (log8f)(float);
extern float (logbfactf)(int, /*@out@*/ int *);
extern float (logbf)(float);
extern float (logf)(float);
extern long int (lrintf)(float);
extern long int (lroundf)(float);
extern float (mchepf)(float);
extern float (modff)(float, /*@out@*/ float *);
extern float (nanf)(const char *);
extern float (nearbyintf)(float);
extern float (nextafterf)(float, float);

#if defined(HAVE_LONG_DOUBLE)

extern float (nexttowardf)(float, long double);

#endif /* defined(HAVE_LONG_DOUBLE) */

extern float (normalizef)(float);
extern const char *(ntosf)(float);
extern float (pgammaf)(int, float);
extern float (phicf)(float);
extern float (phif)(float);
extern float (powf)(float, float);
extern float (psif)(float);
extern float (psilnf)(float);
extern int (qertf)(float, float, float, /*@out@*/ float [/* 2 */], /*@out@*/ float [/* 2 */]);
extern float (qnanf)(const char *);
extern float (quantizef)(float, float);
extern float (remainderf)(float, float);
extern float (remquof)(float, float, /*@out@*/ int *);
extern float (rintf)(float);
extern float (roundf)(float);
extern float (rsqrtf)(float);
extern int (samequantumf)(float, float);
extern float (sbi0f)(float);
extern float (sbi1f)(float);
extern float (sbinf)(int, float);
extern float (sbis0f)(float);
extern float (sbis1f)(float);
extern float (sbisnf)(int, float);
extern float (sbj0f)(float);
extern float (sbj1f)(float);
extern float (sbjnf)(int, float);
extern float (sbk0f)(float);
extern float (sbk1f)(float);
extern float (sbknf)(int, float);
extern float (sbks0f)(float);
extern float (sbks1f)(float);
extern float (sbksnf)(int, float);
extern float (sby0f)(float);
extern float (sby1f)(float);
extern float (sbynf)(int, float);
extern float (scalblnf)(float, long int);
extern float (scalbnf)(float, int);
extern float (secondf)(void);
extern float (setxpf)(float, int);
extern int (signbitf)(float);
extern void (sincosf)(float, /*@out@*/ float *, /*@out@*/ float *);
extern void (sincospf)(float, /*@out@*/ float *, /*@out@*/ float *);
extern void (sincospif)(float, /*@out@*/ float *, /*@out@*/ float *);
extern float (sindegf)(float);
extern float (sinf)(float);
extern void (sinhcoshf)(float, /*@out@*/ float *, /*@out@*/ float *);
extern float (sinhf)(float);
extern float (sinpf)(float);
extern float (sinpif)(float);
extern float (snanf)(const char *);
extern float (sqrtf)(float);
extern float (tandegf)(float);
extern float (tanf)(float);
extern float (tanhf)(float);
extern float (tanpf)(float);
extern float (tanpif)(float);
extern float (tgammaf)(float);
extern float (truncf)(float);
extern float (ulpkf)(double);
extern float (ulpmhf)(double);
extern float (vagmf)(float, float, float, int, /*@out@*/ float [], /*@out@*/ float [], /*@out@*/ float [], /*@out@*/ int *);
extern void (vbif)(int, /*@out@*/ float *, float);
extern void (vbisf)(int, /*@out@*/ float *, float);
extern void (vbjf)(int, /*@out@*/ float *, float);
extern void (vbkf)(int, /*@out@*/ float *, float);
extern void (vbksf)(int, /*@out@*/ float *, float);
extern void (vbyf)(int, /*@out@*/ float *, float);
extern void (_vcopyf)(int, /*@out@*/ float *, float *);
extern void (vsbif)(int, /*@out@*/ float *, float);
extern void (vsbisf)(int, /*@out@*/ float *, float);
extern void (vsbjf)(int, /*@out@*/ float *, float);
extern void (vsbkf)(int, /*@out@*/ float *, float);
extern void (vsbksf)(int, /*@out@*/ float *, float);
extern void (vsbyf)(int, /*@out@*/ float *, float);
extern void (_vsetf)(int, /*@out@*/ float *, float);
extern float (vsumf)(/*@out@*/ float *, int, const float []);
extern float (y0f)(float);
extern float (y1f)(float);
extern float (ynf)(int, float);
extern float (zetaf)(float);
extern float (zetam1f)(float);
extern float (zetnm1f)(int);
extern float (zetnumf)(int);

extern double (acos)(double);
extern double (acosdeg)(double);
extern double (acosh)(double);
extern double (acosp)(double);
extern double (acospi)(double);
extern double (adx)(double, int);
extern double (agm)(double, double);
extern double (annuity)(double, double);
extern double (asin)(double);
extern double (asindeg)(double);
extern double (asinh)(double);
extern double (asinp)(double);
extern double (asinpi)(double);
extern double (atan)(double);
extern double (atan2)(double, double);
extern double (atan2deg)(double, double);
extern double (atan2p)(double, double);
extern double (atan2pi)(double, double);
extern double (atandeg)(double);
extern double (atanh)(double);
extern double (atanp)(double);
extern double (atanpi)(double);
extern double (bernum)(int);
extern double (beta)(double);
extern double (betam1)(double);
extern double (betnm1)(int);
extern double (betnum)(int);
extern double (bi0)(double);
extern double (bis0)(double);
extern double (bi1)(double);
extern double (bis1)(double);
extern double (bin)(int, double);
extern double (binom)(int, int);
extern double (bisn)(int, double);
extern double (bk0)(double);
extern double (bks0)(double);
extern double (bk1)(double);
extern double (bks1)(double);
extern double (bkn)(int, double);
extern double (bksn)(int, double);
extern double (cbrt)(double);
extern double (ceil)(double);
extern double (chisq)(int, double);
extern double (compound)(double, double);
extern double (copysign)(double, double);
extern double (cos)(double);
extern double (cosdeg)(double);
extern double (cosh)(double);
extern double (cosp)(double);
extern double (cospi)(double);
extern double (cotan)(double);
extern double (cotandeg)(double);
extern double (cotanp)(double);
extern double (cotanpi)(double);
extern double (dfact)(int);
extern double (echeb)(double, int, const double []);
extern double (eljaam)(double, double);
extern double (eljacd)(double, double);
extern double (eljacn)(double, double);
extern double (eljacs)(double, double);
extern double (eljadc)(double, double);
extern double (eljadn)(double, double);
extern double (eljads)(double, double);
extern double (eljag)(double, double, int, /*@out@*/ double *, /*@out@*/ double *, /*@out@*/ double *, /*@out@*/ double *, /*@out@*/ int *);
extern double (eljam)(double, double);
extern double (eljanc)(double, double);
extern double (eljand)(double, double);
extern double (eljans)(double, double);
extern double (eljasc)(double, double);
extern double (eljasd)(double, double);
extern double (eljasn)(double, double);
extern double (eljcd)(double, double);
extern double (eljcn)(double, double);
extern double (eljcs)(double, double);
extern double (eljdc)(double, double);
extern double (eljdn)(double, double);
extern double (eljds)(double, double);
extern double (eljh)(double, double);
extern void (eljh4)(/*@out@*/ double[], double, double);
extern double (eljnc)(double, double);
extern double (eljnd)(double, double);
extern double (eljns)(double, double);
extern double (eljsc)(double, double);
extern double (eljsd)(double, double);
extern double (eljsn)(double, double);
extern double (eljt)(double, double);
extern double (eljt1)(double, double);
extern double (eljt2)(double, double);
extern double (eljt3)(double, double);
extern double (eljt4)(double, double);
extern void (eljta)(/*@out@*/ double[], double, double);
extern double (eljtd1)(double, double);
extern double (eljtd2)(double, double);
extern double (eljtd3)(double, double);
extern double (eljtd4)(double, double);
extern void (eljtda)(/*@out@*/ double [], double, double);
extern double (eljz)(double, double);
extern double (elk)(double);
extern double (elkm1)(double);
extern double (elldi)(double, double);
extern double (elle)(double);
extern double (ellec)(double);
extern double (ellk)(double);
extern double (ellei)(double, double);
extern double (ellfi)(double, double);
extern double (ellkc)(double);
extern double (ellkn)(double);
extern double (ellpi)(double, double, double);
extern double (ellrc)(double, double);
extern double (ellrd)(double, double, double);
extern double (ellre)(double, double);
extern double (ellrf)(double, double, double);
extern double (ellrg)(double, double, double);
extern double (ellrh)(double, double, double, double);
extern double (ellrj)(double, double, double, double);
extern double (ellrk)(double, double);
extern double (ellrl)(double, double, double);
extern double (ellrm)(double, double, double);
extern double (elntc)(double, double);
extern double (elntd)(double, double);
extern double (elntn)(double, double);
extern double (elnts)(double, double);
extern double (elq)(double);
extern double (elq1p)(double);
extern double (elqc)(double);
extern double (elqc1p)(double);
extern double (elwdp)(double, double, double);
extern void (elwe)(/*@null@*/ /*@out@*/ double *, /*@null@*/ /*@out@*/ double *, double, double);
extern void (elwg)(/*@null@*/ /*@out@*/ double *, /*@null@*/ /*@out@*/ double *, double, double);
extern double (elwip)(double, double, double);
extern void (elwk)(/*@null@*/ /*@out@*/ double *, /*@null@*/ /*@out@*/ double *, double, double);
extern void (elwo)(/*@null@*/ /*@out@*/ double *, /*@null@*/ /*@out@*/ double *, double, double);
extern double (elwp)(double, double, double);
extern double (elws)(double, double, double);
extern double (elwz)(double, double, double);
extern double (ereduce)(double, double, int, const double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ double *, int);
extern double (erf)(double);
extern double (erfc)(double);
extern double (eriduce)(double, double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ double *, int);
extern double (exp)(double);
extern double (eulnum)(int);
extern double (exp10)(double);
extern double (exp10m1)(double);
extern double (exp16)(double);
extern double (exp16m1)(double);
extern double (exp2)(double);
extern double (exp2m1)(double);
extern double (exp8)(double);
extern double (exp8m1)(double);
extern double (expm1)(double);
extern double (fabs)(double);
extern double (fact)(int);
extern double (fdim)(double, double);
extern double (fibnum)(int);
extern double (floor)(double);
extern double (fma)(double, double, double);
extern double (fmax)(double, double);
extern double (fmin)(double, double);
extern double (fmod)(double, double);
extern void (fmul)(/*@out@*/ double [/* 2 */], double, double);
extern int (fpclassify)(double);
extern double (frexp)(double, /*@out@*/ int *);
extern double (frexph)(double, /*@out@*/ int *);
extern double (frexpo)(double, /*@out@*/ int *);
extern double (gami)(double, double);
extern void (gamib)(/*@out@*/ double [/* 2 */], double, double);
extern double (gamic)(double, double);
extern double (hypot)(double, double);
extern double (ichisq)(int, double);
extern double (ierf)(double);
extern double (ierfc)(double);
extern int (ilogb)(double);
extern double (infty)(void);
extern int (intxp)(double);
extern double (iphi)(double);
extern double (iphic)(double);
extern double (ipow)(double, int);
extern int (isfinite)(double);
extern int (isgreater)(double, double);
extern int (isgreaterequal)(double, double);
extern int (isinf)(double);
extern int (isless)(double, double);
extern int (islessequal)(double, double);
extern int (islessgreater)(double, double);
extern int (isnan)(double);
extern int (isnormal)(double);
extern int (isqnan)(double);
extern int (issnan)(double);
extern int (issubnormal)(double);
extern int (isunordered)(double, double);
extern double (j0)(double);
extern double (j1)(double);
extern double (jn)(int, double);
extern double (ldexp)(double, int);
extern double (ldexph)(double, int);
extern double (ldexpo)(double, int);
extern double (lgamma)(double);
extern double (lgamma_r)(double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrint)(double);
extern long long int (llround)(double);
#endif

extern double (log)(double);
extern double (log10)(double);
extern double (log101p)(double);
extern double (log16)(double);
extern double (log161p)(double);
extern double (log1p)(double);
extern double (log2)(double);
extern double (log21p)(double);
extern double (log8)(double);
extern double (log81p)(double);
extern double (logbfact)(int, /*@out@*/ int *);
extern double (logb)(double);
extern long int (lrint)(double);
extern long int (lround)(double);
extern double (mchep)(double);
extern double (modf)(double, /*@out@*/ double *);
extern double (nan)(const char *);
extern double (nearbyint)(double);
extern double (nextafter)(double, double);

#if defined(HAVE_LONG_DOUBLE)

extern double (nexttoward)(double, long double);

#endif /* defined(HAVE_LONG_DOUBLE) */

extern double (normalize)(double);
extern const char *(ntos)(double);
extern double (phi)(double);
extern double (pgamma)(int, double);
extern double (phic)(double);
extern double (pow)(double, double);
extern double (psi)(double);
extern double (psiln)(double);
extern int (qert)(double, double, double, /*@out@*/ double [/* 2 */], /*@out@*/ double [/* 2 */]);
extern double (qnan)(const char *);
extern double (quantize)(double, double);
extern double (remainder)(double, double);
extern double (remquo)(double, double, /*@out@*/ int *);
extern double (rint)(double);
extern double (round)(double);
extern double (rsqrt)(double);
extern int (samequantum)(double, double);
extern double (sbi0)(double);
extern double (sbi1)(double);
extern double (sbin)(int, double);
extern double (sbis0)(double);
extern double (sbis1)(double);
extern double (sbisn)(int, double);
extern double (sbj0)(double);
extern double (sbj1)(double);
extern double (sbjn)(int, double);
extern double (sbk0)(double);
extern double (sbk1)(double);
extern double (sbkn)(int, double);
extern double (sbks0)(double);
extern double (sbks1)(double);
extern double (sbksn)(int, double);
extern double (sby0)(double);
extern double (sby1)(double);
extern double (sbyn)(int, double);
extern double (scalbln)(double, long int);
extern double (scalbn)(double, int);
extern double (second)(void);
extern double (setxp)(double, int);
extern int (signbit)(double);
extern double (sin)(double);
extern void (sincos)(double, /*@out@*/ double *, /*@out@*/ double *);
extern void (sincosp)(double, /*@out@*/ double *, /*@out@*/ double *);
extern void (sincospi)(double, /*@out@*/ double *, /*@out@*/ double *);
extern double (sindeg)(double);
extern double (sinh)(double);
extern void (sinhcosh)(double, /*@out@*/ double *, /*@out@*/ double *);
extern double (sinp)(double);
extern double (sinpi)(double);
extern double (snan)(const char *);
extern double (sqrt)(double);
extern double (tan)(double);
extern double (tandeg)(double);
extern double (tanh)(double);
extern double (tanp)(double);
extern double (tanpi)(double);
extern double (tgamma)(double);
extern double (trunc)(double);

#if defined(HAVE_LONG_DOUBLE)

extern double (ulpk)(long double);
extern double (ulpmh)(long double);

#endif /* defined(HAVE_LONG_DOUBLE) */

extern double (vagm)(double, double, double, int, /*@out@*/ double [], /*@out@*/ double [], /*@out@*/ double [], /*@out@*/ int *);
extern void (vbi)(int, /*@out@*/ double *, double);
extern void (vbis)(int, /*@out@*/ double *, double);
extern void (vbj)(int, /*@out@*/ double *, double);
extern void (vbk)(int, /*@out@*/ double *, double);
extern void (vbks)(int, /*@out@*/ double *, double);
extern void (vby)(int, /*@out@*/ double *, double);
extern void (_vcopy)(int, /*@out@*/ double *, double *);
extern void (vsbi)(int, /*@out@*/ double *, double);
extern void (vsbis)(int, /*@out@*/ double *, double);
extern void (vsbj)(int, /*@out@*/ double *, double);
extern void (vsbk)(int, /*@out@*/ double *, double);
extern void (vsbks)(int, /*@out@*/ double *, double);
extern void (vsby)(int, /*@out@*/ double *, double);
extern void (_vset)(int, /*@out@*/ double *, double);
extern double (vsum)(/*@out@*/ double *, int, const double []);
extern double (y0)(double);
extern double (y1)(double);
extern double (yn)(int, double);
extern double (zeta)(double);
extern double (zetam1)(double);
extern double (zetnm1)(int);
extern double (zetnum)(int);

#if defined(HAVE_LONG_DOUBLE)

extern long double (acosdegl)(long double);
extern long double (acoshl)(long double);
extern long double (acosl)(long double);
extern long double (acospil)(long double);
extern long double (acospl)(long double);
extern long double (adxl)(long double, int);
extern long double (agml)(long double, long double);
extern long double (annuityl)(long double, long double);
extern long double (asindegl)(long double);
extern long double (asinhl)(long double);
extern long double (asinl)(long double);
extern long double (asinpil)(long double);
extern long double (asinpl)(long double);
extern long double (atan2degl)(long double, long double);
extern long double (atan2l)(long double, long double);
extern long double (atan2pl)(long double, long double);
extern long double (atan2pil)(long double, long double);
extern long double (atandegl)(long double);
extern long double (atanhl)(long double);
extern long double (atanl)(long double);
extern long double (atanpil)(long double);
extern long double (atanpl)(long double);
extern long double (bernuml)(int);
extern long double (betal)(long double);
extern long double (betam1l)(long double);
extern long double (betnm1l)(int);
extern long double (betnuml)(int);
extern long double (bi0l)(long double);
extern long double (bis0l)(long double);
extern long double (bi1l)(long double);
extern long double (bis1l)(long double);
extern long double (binl)(int, long double);
extern long double (binoml)(int, int);
extern long double (bisnl)(int, long double);
extern long double (bk0l)(long double);
extern long double (bks0l)(long double);
extern long double (bk1l)(long double);
extern long double (bks1l)(long double);
extern long double (bknl)(int, long double);
extern long double (bksnl)(int, long double);
extern long double (cbrtl)(long double);
extern long double (ceill)(long double);
extern long double (chisql)(int, long double);
extern long double (compoundl)(long double, long double);
extern long double (copysignl)(long double, long double);
extern long double (cosdegl)(long double);
extern long double (coshl)(long double);
extern long double (cosl)(long double);
extern long double (cospil)(long double);
extern long double (cospl)(long double);
extern long double (cotandegl)(long double);
extern long double (cotanl)(long double);
extern long double (cotanpil)(long double);
extern long double (cotanpl)(long double);
extern long double (dfactl)(int);
extern long double (echebl)(long double, int, const long double []);
extern long double (eljaaml)(long double, long double);
extern long double (eljacdl)(long double, long double);
extern long double (eljacnl)(long double, long double);
extern long double (eljacsl)(long double, long double);
extern long double (eljadcl)(long double, long double);
extern long double (eljadnl)(long double, long double);
extern long double (eljadsl)(long double, long double);
extern long double (eljagl)(long double, long double, int, /*@out@*/ long double *, /*@out@*/ long double *, /*@out@*/ long double *, /*@out@*/ long double *, /*@out@*/ int *);
extern long double (eljaml)(long double, long double);
extern long double (eljancl)(long double, long double);
extern long double (eljandl)(long double, long double);
extern long double (eljansl)(long double, long double);
extern long double (eljascl)(long double, long double);
extern long double (eljasdl)(long double, long double);
extern long double (eljasnl)(long double, long double);
extern long double (eljcdl)(long double, long double);
extern long double (eljcnl)(long double, long double);
extern long double (eljcsl)(long double, long double);
extern long double (eljdcl)(long double, long double);
extern long double (eljdnl)(long double, long double);
extern long double (eljdsl)(long double, long double);
extern long double (eljhl)(long double, long double);
extern void (eljh4l)(/*@out@*/ long double[], long double, long double);
extern long double (eljncl)(long double, long double);
extern long double (eljndl)(long double, long double);
extern long double (eljnsl)(long double, long double);
extern long double (eljscl)(long double, long double);
extern long double (eljsdl)(long double, long double);
extern long double (eljsnl)(long double, long double);
extern long double (eljtl)(long double, long double);
extern long double (eljt1l)(long double, long double);
extern long double (eljt2l)(long double, long double);
extern long double (eljt3l)(long double, long double);
extern long double (eljt4l)(long double, long double);
extern void (eljtal)(/*@out@*/ long double[], long double, long double);
extern long double (eljtd1l)(long double, long double);
extern long double (eljtd2l)(long double, long double);
extern long double (eljtd3l)(long double, long double);
extern long double (eljtd4l)(long double, long double);
extern void (eljtdal)(/*@out@*/ long double [], long double, long double);
extern long double (eljzl)(long double, long double);
extern long double (elkl)(long double);
extern long double (elkm1l)(long double);
extern long double (elldil)(long double, long double);
extern long double (ellecl)(long double);
extern long double (ellel)(long double);
extern long double (elleil)(long double, long double);
extern long double (ellfil)(long double, long double);
extern long double (ellkcl)(long double);
extern long double (ellkl)(long double);
extern long double (ellknl)(long double);
extern long double (ellpil)(long double, long double, long double);
extern long double (ellrcl)(long double, long double);
extern long double (ellrdl)(long double, long double, long double);
extern long double (ellrel)(long double, long double);
extern long double (ellrfl)(long double, long double, long double);
extern long double (ellrgl)(long double, long double, long double);
extern long double (ellrhl)(long double, long double, long double, long double);
extern long double (ellrjl)(long double, long double, long double, long double);
extern long double (ellrkl)(long double, long double);
extern long double (ellrll)(long double, long double, long double);
extern long double (ellrml)(long double, long double, long double);
extern long double (elntcl)(long double, long double);
extern long double (elntdl)(long double, long double);
extern long double (elntnl)(long double, long double);
extern long double (elntsl)(long double, long double);
extern long double (elql)(long double);
extern long double (elq1pl)(long double);
extern long double (elqcl)(long double);
extern long double (elqc1pl)(long double);
extern long double (elwdpl)(long double, long double, long double);
extern void (elwel)(/*@null@*/ /*@out@*/ long double *, /*@null@*/ /*@out@*/ long double *, long double, long double);
extern void (elwgl)(/*@null@*/ /*@out@*/ long double *, /*@null@*/ /*@out@*/ long double *, long double, long double);
extern long double (elwipl)(long double, long double, long double);
extern void (elwkl)(/*@null@*/ /*@out@*/ long double *, /*@null@*/ /*@out@*/ long double *, long double, long double);
extern void (elwol)(/*@null@*/ /*@out@*/ long double *, /*@null@*/ /*@out@*/ long double *, long double, long double);
extern long double (elwpl)(long double, long double, long double);
extern long double (elwsl)(long double, long double, long double);
extern long double (elwzl)(long double, long double, long double);
extern long double (ereducel)(long double, long double, int, const long double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ long double *, int);
extern long double (erfcl)(long double);
extern long double (erfl)(long double);
extern long double (eriducel)(long double, long double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ long double *, int);
extern long double (eulnuml)(int);
extern long double (exp10l)(long double);
extern long double (exp10m1l)(long double);
extern long double (exp16l)(long double);
extern long double (exp16m1l)(long double);
extern long double (exp2l)(long double);
extern long double (exp2m1l)(long double);
extern long double (exp8l)(long double);
extern long double (exp8m1l)(long double);
extern long double (expl)(long double);
extern long double (expm1l)(long double);
extern long double (fabsl)(long double);
extern long double (factl)(int);
extern long double (fdiml)(long double, long double);
extern long double (fibnuml)(int);
extern long double (floorl)(long double);
extern long double (fmal)(long double, long double, long double);
extern long double (fmaxl)(long double, long double);
extern long double (fminl)(long double, long double);
extern long double (fmodl)(long double, long double);
extern void (fmull)(/*@out@*/ long double [/* 2 */], long double, long double);
extern int (fpclassifyl)(long double);
extern long double (frexphl)(long double, /*@out@*/ int *);
extern long double (frexpl)(long double, /*@out@*/ int *);
extern long double (frexpol)(long double, /*@out@*/ int *);
extern void (gamibl)(/*@out@*/ long double [/* 2 */], long double, long double);
extern long double (gamicl)(long double, long double);
extern long double (gamil)(long double, long double);
extern long double (hypotl)(long double, long double);
extern long double (ichisql)(int, long double);
extern long double (ierfcl)(long double);
extern long double (ierfl)(long double);
extern int (ilogbl)(long double);
extern long double (inftyl)(void);
extern int (intxpl)(long double);
extern long double (iphicl)(long double);
extern long double (iphil)(long double);
extern long double (ipowl)(long double, int);
extern int (isfinitel)(long double);
extern int (isgreaterequall)(long double, long double);
extern int (isgreaterl)(long double, long double);
extern int (isinfl)(long double);
extern int (islessequall)(long double, long double);
extern int (islessgreaterl)(long double, long double);
extern int (islessl)(long double, long double);
extern int (isnanl)(long double);
extern int (isnormall)(long double);
extern int (isqnanl)(long double);
extern int (issnanl)(long double);
extern int (issubnormall)(long double);
extern int (isunorderedl)(long double, long double);
extern long double (j0l)(long double);
extern long double (j1l)(long double);
extern long double (jnl)(int, long double);
extern long double (ldexphl)(long double, int);
extern long double (ldexpl)(long double, int);
extern long double (ldexpol)(long double, int);
extern long double (lgammal)(long double);
extern long double (lgammal_r)(long double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintl)(long double);
extern long long int (llroundl)(long double);
#endif

extern long double (log101pl)(long double);
extern long double (log10l)(long double);
extern long double (log161pl)(long double);
extern long double (log16l)(long double);
extern long double (log1pl)(long double);
extern long double (log21pl)(long double);
extern long double (log2l)(long double);
extern long double (log81pl)(long double);
extern long double (log8l)(long double);
extern long double (logbfactl)(int, /*@out@*/ int *);
extern long double (logbl)(long double);
extern long double (logl)(long double);
extern long int (lrintl)(long double);
extern long int (lroundl)(long double);
extern long double (mchepl)(long double);
extern long double (modfl)(long double, /*@out@*/ long double *);
extern long double (nanl)(const char *);
extern long double (nearbyintl)(long double);
extern long double (nextafterl)(long double, long double);
extern long double (nexttowardl)(long double, long double);
extern long double (normalizel)(long double);
extern const char *(ntosl)(long double);
extern long double (pgammal)(int, long double);
extern long double (phicl)(long double);
extern long double (phil)(long double);
extern long double (powl)(long double, long double);
extern long double (psil)(long double);
extern long double (psilnl)(long double);
extern int (qertl)(long double, long double, long double, /*@out@*/ long double [/* 2 */], /*@out@*/ long double [/* 2 */]);
extern long double (qnanl)(const char *);
extern long double (quantizel)(long double, long double);
extern long double (remainderl)(long double, long double);
extern long double (remquol)(long double, long double, /*@out@*/ int *);
extern long double (rintl)(long double);
extern long double (roundl)(long double);
extern long double (rsqrtl)(long double);
extern int (samequantuml)(long double, long double);
extern long double (sbi0l)(long double);
extern long double (sbi1l)(long double);
extern long double (sbinl)(int, long double);
extern long double (sbis0l)(long double);
extern long double (sbis1l)(long double);
extern long double (sbisnl)(int, long double);
extern long double (sbj0l)(long double);
extern long double (sbj1l)(long double);
extern long double (sbjnl)(int, long double);
extern long double (sbk0l)(long double);
extern long double (sbk1l)(long double);
extern long double (sbknl)(int, long double);
extern long double (sbks0l)(long double);
extern long double (sbks1l)(long double);
extern long double (sbksnl)(int, long double);
extern long double (sby0l)(long double);
extern long double (sby1l)(long double);
extern long double (sbynl)(int, long double);
extern long double (scalblnl)(long double, long int);
extern long double (scalbnl)(long double, int);
extern long double (secondl)(void);
extern long double (setxpl)(long double, int);
extern int (signbitl)(long double);
extern void (sincosl)(long double, /*@out@*/ long double *, /*@out@*/ long double *);
extern void (sincospil)(long double, /*@out@*/ long double *, /*@out@*/ long double *);
extern void (sincospl)(long double, /*@out@*/ long double *, /*@out@*/ long double *);
extern long double (sindegl)(long double);
extern void (sinhcoshl)(long double, /*@out@*/ long double *, /*@out@*/ long double *);
extern long double (sinhl)(long double);
extern long double (sinl)(long double);
extern long double (sinpil)(long double);
extern long double (sinpl)(long double);
extern long double (snanl)(const char *);
extern long double (sqrtl)(long double);
extern long double (tandegl)(long double);
extern long double (tanhl)(long double);
extern long double (tanl)(long double);
extern long double (tanpil)(long double);
extern long double (tanpl)(long double);
extern long double (tgammal)(long double);
extern long double (truncl)(long double);
extern long double (ulpkl)(long_long_double);
extern long double (ulpmhl)(long_long_double);
extern long double (vagml)(long double, long double, long double, int, /*@out@*/ long double [], /*@out@*/ long double [], /*@out@*/ long double [], /*@out@*/ int *);
extern void (vbil)(int, /*@out@*/ long double *, long double);
extern void (vbisl)(int, /*@out@*/ long double *, long double);
extern void (vbjl)(int, /*@out@*/ long double *, long double);
extern void (vbkl)(int, /*@out@*/ long double *, long double);
extern void (vbksl)(int, /*@out@*/ long double *, long double);
extern void (vbyl)(int, /*@out@*/ long double *, long double);
extern void (_vcopyl)(int, /*@out@*/ long double *, long double *);
extern void (vsbil)(int, /*@out@*/ long double *, long double);
extern void (vsbisl)(int, /*@out@*/ long double *, long double);
extern void (vsbjl)(int, /*@out@*/ long double *, long double);
extern void (vsbkl)(int, /*@out@*/ long double *, long double);
extern void (vsbksl)(int, /*@out@*/ long double *, long double);
extern void (vsbyl)(int, /*@out@*/ long double *, long double);
extern void (_vsetl)(int, /*@out@*/ long double *, long double);
extern long double (vsuml)(/*@out@*/ long double *, int, const long double []);
extern long double (y0l)(long double);
extern long double (y1l)(long double);
extern long double (ynl)(int, long double);
extern long double (zetal)(long double);
extern long double (zetam1l)(long double);
extern long double (zetnm1l)(int);
extern long double (zetnuml)(int);

#endif /* defined(HAVE_LONG_DOUBLE) */

#if defined(HAVE_LONG_LONG_DOUBLE)

extern long_long_double (acosdegll)(long_long_double);
extern long_long_double (acoshll)(long_long_double);
extern long_long_double (acosll)(long_long_double);
extern long_long_double (acospill)(long_long_double);
extern long_long_double (acospll)(long_long_double);
extern long_long_double (adxll)(long_long_double, int);
extern long_long_double (agmll)(long_long_double, long_long_double);
extern long_long_double (annuityll)(long_long_double, long_long_double);
extern long_long_double (asindegll)(long_long_double);
extern long_long_double (asinhll)(long_long_double);
extern long_long_double (asinll)(long_long_double);
extern long_long_double (asinpill)(long_long_double);
extern long_long_double (asinpll)(long_long_double);
extern long_long_double (atan2degll)(long_long_double, long_long_double);
extern long_long_double (atan2ll)(long_long_double, long_long_double);
extern long_long_double (atan2pll)(long_long_double, long_long_double);
extern long_long_double (atan2pill)(long_long_double, long_long_double);
extern long_long_double (atandegll)(long_long_double);
extern long_long_double (atanhll)(long_long_double);
extern long_long_double (atanll)(long_long_double);
extern long_long_double (atanpill)(long_long_double);
extern long_long_double (atanpll)(long_long_double);
extern long_long_double (bernumll)(int);
extern long_long_double (betall)(long_long_double);
extern long_long_double (betam1ll)(long_long_double);
extern long_long_double (betnm1ll)(int);
extern long_long_double (betnumll)(int);
extern long_long_double (bi0ll)(long_long_double);
extern long_long_double (bis0ll)(long_long_double);
extern long_long_double (bi1ll)(long_long_double);
extern long_long_double (bis1ll)(long_long_double);
extern long_long_double (binll)(int, long_long_double);
extern long_long_double (binomll)(int, int);
extern long_long_double (bisnll)(int, long_long_double);
extern long_long_double (bk0ll)(long_long_double);
extern long_long_double (bks0ll)(long_long_double);
extern long_long_double (bk1ll)(long_long_double);
extern long_long_double (bks1ll)(long_long_double);
extern long_long_double (bknll)(int, long_long_double);
extern long_long_double (bksnll)(int, long_long_double);
extern long_long_double (cbrtll)(long_long_double);
extern long_long_double (ceilll)(long_long_double);
extern long_long_double (chisqll)(int, long_long_double);
extern long_long_double (compoundll)(long_long_double, long_long_double);
extern long_long_double (copysignll)(long_long_double, long_long_double);
extern long_long_double (cosdegll)(long_long_double);
extern long_long_double (coshll)(long_long_double);
extern long_long_double (cosll)(long_long_double);
extern long_long_double (cospill)(long_long_double);
extern long_long_double (cospll)(long_long_double);
extern long_long_double (cotandegll)(long_long_double);
extern long_long_double (cotanll)(long_long_double);
extern long_long_double (cotanpill)(long_long_double);
extern long_long_double (cotanpll)(long_long_double);
extern long_long_double (dfactll)(int);
extern long_long_double (echebll)(long_long_double, int, const long_long_double []);
extern long_long_double (eljaamll)(long_long_double, long_long_double);
extern long_long_double (eljacdll)(long_long_double, long_long_double);
extern long_long_double (eljacnll)(long_long_double, long_long_double);
extern long_long_double (eljacsll)(long_long_double, long_long_double);
extern long_long_double (eljadcll)(long_long_double, long_long_double);
extern long_long_double (eljadnll)(long_long_double, long_long_double);
extern long_long_double (eljadsll)(long_long_double, long_long_double);
extern long_long_double (eljagll)(long_long_double, long_long_double, int, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *, /*@out@*/ int *);
extern long_long_double (eljamll)(long_long_double, long_long_double);
extern long_long_double (eljancll)(long_long_double, long_long_double);
extern long_long_double (eljandll)(long_long_double, long_long_double);
extern long_long_double (eljansll)(long_long_double, long_long_double);
extern long_long_double (eljascll)(long_long_double, long_long_double);
extern long_long_double (eljasdll)(long_long_double, long_long_double);
extern long_long_double (eljasnll)(long_long_double, long_long_double);
extern long_long_double (eljcdll)(long_long_double, long_long_double);
extern long_long_double (eljcnll)(long_long_double, long_long_double);
extern long_long_double (eljcsll)(long_long_double, long_long_double);
extern long_long_double (eljdcll)(long_long_double, long_long_double);
extern long_long_double (eljdnll)(long_long_double, long_long_double);
extern long_long_double (eljdsll)(long_long_double, long_long_double);
extern long_long_double (eljhll)(long_long_double, long_long_double);
extern void (eljh4ll)(/*@out@*/ long_long_double[], long_long_double, long_long_double);
extern long_long_double (eljncll)(long_long_double, long_long_double);
extern long_long_double (eljndll)(long_long_double, long_long_double);
extern long_long_double (eljnsll)(long_long_double, long_long_double);
extern long_long_double (eljscll)(long_long_double, long_long_double);
extern long_long_double (eljsdll)(long_long_double, long_long_double);
extern long_long_double (eljsnll)(long_long_double, long_long_double);
extern long_long_double (eljtll)(long_long_double, long_long_double);
extern long_long_double (eljt1ll)(long_long_double, long_long_double);
extern long_long_double (eljt2ll)(long_long_double, long_long_double);
extern long_long_double (eljt3ll)(long_long_double, long_long_double);
extern long_long_double (eljt4ll)(long_long_double, long_long_double);
extern void (eljtall)(/*@out@*/ long_long_double[], long_long_double, long_long_double);
extern long_long_double (eljtd1ll)(long_long_double, long_long_double);
extern long_long_double (eljtd2ll)(long_long_double, long_long_double);
extern long_long_double (eljtd3ll)(long_long_double, long_long_double);
extern long_long_double (eljtd4ll)(long_long_double, long_long_double);
extern void (eljtdall)(/*@out@*/ long_long_double [], long_long_double, long_long_double);
extern long_long_double (eljzll)(long_long_double, long_long_double);
extern long_long_double (elkll)(long_long_double);
extern long_long_double (elkm1ll)(long_long_double);
extern long_long_double (elldill)(long_long_double, long_long_double);
extern long_long_double (ellecll)(long_long_double);
extern long_long_double (ellell)(long_long_double);
extern long_long_double (elleill)(long_long_double, long_long_double);
extern long_long_double (ellfill)(long_long_double, long_long_double);
extern long_long_double (ellkcll)(long_long_double);
extern long_long_double (ellkll)(long_long_double);
extern long_long_double (ellknll)(long_long_double);
extern long_long_double (ellpill)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrcll)(long_long_double, long_long_double);
extern long_long_double (ellrdll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrell)(long_long_double, long_long_double);
extern long_long_double (ellrfll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrgll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrhll)(long_long_double, long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrjll)(long_long_double, long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrkll)(long_long_double, long_long_double);
extern long_long_double (ellrlll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ellrmll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (elntcll)(long_long_double, long_long_double);
extern long_long_double (elntdll)(long_long_double, long_long_double);
extern long_long_double (elntnll)(long_long_double, long_long_double);
extern long_long_double (elntsll)(long_long_double, long_long_double);
extern long_long_double (elqll)(long_long_double);
extern long_long_double (elq1pll)(long_long_double);
extern long_long_double (elqcll)(long_long_double);
extern long_long_double (elqc1pll)(long_long_double);
extern long_long_double (elwdpll)(long_long_double, long_long_double, long_long_double);
extern void (elwell)(/*@null@*/ /*@out@*/ long_long_double *, /*@null@*/ /*@out@*/ long_long_double *, long_long_double, long_long_double);
extern void (elwgll)(/*@null@*/ /*@out@*/ long_long_double *, /*@null@*/ /*@out@*/ long_long_double *, long_long_double, long_long_double);
extern long_long_double (elwipll)(long_long_double, long_long_double, long_long_double);
extern void (elwkll)(/*@null@*/ /*@out@*/ long_long_double *, /*@null@*/ /*@out@*/ long_long_double *, long_long_double, long_long_double);
extern void (elwoll)(/*@null@*/ /*@out@*/ long_long_double *, /*@null@*/ /*@out@*/ long_long_double *, long_long_double, long_long_double);
extern long_long_double (elwpll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (elwsll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (elwzll)(long_long_double, long_long_double, long_long_double);
extern long_long_double (ereducell)(long_long_double, long_long_double, int, const long_long_double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ long_long_double *, int);
extern long_long_double (erfcll)(long_long_double);
extern long_long_double (erfll)(long_long_double);
extern long_long_double (eriducell)(long_long_double, long_long_double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ long_long_double *, int);
extern long_long_double (eulnumll)(int);
extern long_long_double (exp10ll)(long_long_double);
extern long_long_double (exp10m1ll)(long_long_double);
extern long_long_double (exp16ll)(long_long_double);
extern long_long_double (exp16m1ll)(long_long_double);
extern long_long_double (exp2ll)(long_long_double);
extern long_long_double (exp2m1ll)(long_long_double);
extern long_long_double (exp8ll)(long_long_double);
extern long_long_double (exp8m1ll)(long_long_double);
extern long_long_double (expll)(long_long_double);
extern long_long_double (expm1ll)(long_long_double);
extern long_long_double (fabsll)(long_long_double);
extern long_long_double (factll)(int);
extern long_long_double (fdimll)(long_long_double, long_long_double);
extern long_long_double (fibnumll)(int);
extern long_long_double (floorll)(long_long_double);
extern long_long_double (fmall)(long_long_double, long_long_double, long_long_double);
extern long_long_double (fmaxll)(long_long_double, long_long_double);
extern long_long_double (fminll)(long_long_double, long_long_double);
extern long_long_double (fmodll)(long_long_double, long_long_double);
extern void (fmulll)(/*@out@*/ long_long_double [/* 2 */], long_long_double, long_long_double);
extern int (fpclassifyll)(long_long_double);
extern long_long_double (frexphll)(long_long_double, /*@out@*/ int *);
extern long_long_double (frexpll)(long_long_double, /*@out@*/ int *);
extern long_long_double (frexpoll)(long_long_double, /*@out@*/ int *);
extern void (gamibll)(/*@out@*/ long_long_double[/* 2 */], long_long_double, long_long_double);
extern long_long_double (gamicll)(long_long_double, long_long_double);
extern long_long_double (gamill)(long_long_double, long_long_double);
extern long_long_double (hypotll)(long_long_double, long_long_double);
extern long_long_double (ichisqll)(int, long_long_double);
extern long_long_double (ierfcll)(long_long_double);
extern long_long_double (ierfll)(long_long_double);
extern int (ilogbll)(long_long_double);
extern long_long_double (inftyll)(void);
extern int (intxpll)(long_long_double);
extern long_long_double (iphicll)(long_long_double);
extern long_long_double (iphill)(long_long_double);
extern long_long_double (ipowll)(long_long_double, int);
extern int (isfinitell)(long_long_double);
extern int (isgreaterequalll)(long_long_double, long_long_double);
extern int (isgreaterll)(long_long_double, long_long_double);
extern int (isinfll)(long_long_double);
extern int (islessequalll)(long_long_double, long_long_double);
extern int (islessgreaterll)(long_long_double, long_long_double);
extern int (islessll)(long_long_double, long_long_double);
extern int (isnanll)(long_long_double);
extern int (isnormalll)(long_long_double);
extern int (isqnanll)(long_long_double);
extern int (issnanll)(long_long_double);
extern int (issubnormalll)(long_long_double);
extern int (isunorderedll)(long_long_double, long_long_double);
extern long_long_double (j0ll)(long_long_double);
extern long_long_double (j1ll)(long_long_double);
extern long_long_double (jnll)(int, long_long_double);
extern long_long_double (ldexphll)(long_long_double, int);
extern long_long_double (ldexpll)(long_long_double, int);
extern long_long_double (ldexpoll)(long_long_double, int);
extern long_long_double (lgammall)(long_long_double);
extern long_long_double (lgammall_r)(long_long_double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintll)(long_long_double);
extern long long int (llroundll)(long_long_double);
#endif

extern long_long_double (log101pll)(long_long_double);
extern long_long_double (log10ll)(long_long_double);
extern long_long_double (log161pll)(long_long_double);
extern long_long_double (log16ll)(long_long_double);
extern long_long_double (log1pll)(long_long_double);
extern long_long_double (log21pll)(long_long_double);
extern long_long_double (log2ll)(long_long_double);
extern long_long_double (log81pll)(long_long_double);
extern long_long_double (log8ll)(long_long_double);
extern long_long_double (logbfactll)(int, /*@out@*/ int *);
extern long_long_double (logbll)(long_long_double);
extern long_long_double (logll)(long_long_double);
extern long int (lrintll)(long_long_double);
extern long int (lroundll)(long_long_double);
extern long_long_double (mchepll)(long_long_double);
extern long_long_double (modfll)(long_long_double, /*@out@*/ long_long_double *);
extern long_long_double (nanll)(const char *);
extern long_long_double (nearbyintll)(long_long_double);
extern long_long_double (nextafterll)(long_long_double, long_long_double);
extern long_long_double (nexttowardll)(long_long_double, long_long_double);
extern long_long_double (normalizell)(long_long_double);
extern const char	*(ntosll)(long_long_double);
extern long_long_double (pgammall)(int, long_long_double);
extern long_long_double (phicll)(long_long_double);
extern long_long_double (phill)(long_long_double);
extern long_long_double (powll)(long_long_double, long_long_double);
extern long_long_double (psill)(long_long_double);
extern long_long_double (psilnll)(long_long_double);
extern int (qertll)(long_long_double, long_long_double, long_long_double, /*@out@*/ long_long_double [/* 2 */], /*@out@*/ long_long_double [/* 2 */]);
extern long_long_double (qnanll)(const char *);
extern long_long_double (quantizell)(long_long_double, long_long_double);
extern long_long_double (remainderll)(long_long_double, long_long_double);
extern long_long_double (remquoll)(long_long_double, long_long_double, /*@out@*/ int *);
extern long_long_double (rintll)(long_long_double);
extern long_long_double (roundll)(long_long_double);
extern long_long_double (rsqrtll)(long_long_double);
extern int (samequantumll)(long_long_double, long_long_double);
extern long_long_double (sbi0ll)(long_long_double);
extern long_long_double (sbi1ll)(long_long_double);
extern long_long_double (sbinll)(int, long_long_double);
extern long_long_double (sbis0ll)(long_long_double);
extern long_long_double (sbis1ll)(long_long_double);
extern long_long_double (sbisnll)(int, long_long_double);
extern long_long_double (sbj0ll)(long_long_double);
extern long_long_double (sbj1ll)(long_long_double);
extern long_long_double (sbjnll)(int, long_long_double);
extern long_long_double (sbk0ll)(long_long_double);
extern long_long_double (sbk1ll)(long_long_double);
extern long_long_double (sbknll)(int, long_long_double);
extern long_long_double (sbks0ll)(long_long_double);
extern long_long_double (sbks1ll)(long_long_double);
extern long_long_double (sbksnll)(int, long_long_double);
extern long_long_double (sby0ll)(long_long_double);
extern long_long_double (sby1ll)(long_long_double);
extern long_long_double (sbynll)(int, long_long_double);
extern long_long_double (scalblnll)(long_long_double, long int);
extern long_long_double (scalbnll)(long_long_double, int);
extern long_long_double (secondll)(void);
extern long_long_double (setxpll)(long_long_double, int);
extern int (signbitll)(long_long_double);
extern void (sincosll)(long_long_double, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *);
extern void (sincospill)(long_long_double, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *);
extern void (sincospll)(long_long_double, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *);
extern long_long_double (sindegll)(long_long_double);
extern void (sinhcoshll)(long_long_double, /*@out@*/ long_long_double *, /*@out@*/ long_long_double *);
extern long_long_double (sinhll)(long_long_double);
extern long_long_double (sinll)(long_long_double);
extern long_long_double (sinpill)(long_long_double);
extern long_long_double (sinpll)(long_long_double);
extern long_long_double (snanll)(const char *);
extern long_long_double (sqrtll)(long_long_double);
extern long_long_double (tandegll)(long_long_double);
extern long_long_double (tanhll)(long_long_double);
extern long_long_double (tanll)(long_long_double);
extern long_long_double (tanpill)(long_long_double);
extern long_long_double (tanpll)(long_long_double);
extern long_long_double (tgammall)(long_long_double);
extern long_long_double (truncll)(long_long_double);
extern long_long_double (ulpkll)(long_long_double);
extern long_long_double (ulpmhll)(long_long_double);
extern long_long_double (vagmll)(long_long_double, long_long_double, long_long_double, int, /*@out@*/ long_long_double [], /*@out@*/ long_long_double [], /*@out@*/ long_long_double [], /*@out@*/ int *);
extern void (vbill)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vbisll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vbjll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vbkll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vbksll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vbyll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (_vcopyll)(int, /*@out@*/ long_long_double *, long_long_double *);
extern void (vsbill)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vsbisll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vsbjll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vsbkll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vsbksll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (vsbyll)(int, /*@out@*/ long_long_double *, long_long_double);
extern void (_vsetll)(int, /*@out@*/ long_long_double *, long_long_double);
extern long_long_double (vsumll)(/*@out@*/ long_long_double *, int, const long_long_double []);
extern long_long_double (y0ll)(long_long_double);
extern long_long_double (y1ll)(long_long_double);
extern long_long_double (ynll)(int, long_long_double);
extern long_long_double (zetall)(long_long_double);
extern long_long_double (zetam1ll)(long_long_double);
extern long_long_double (zetnm1ll)(int);
extern long_long_double (zetnumll)(int);

#endif /* defined(HAVE_LONG_LONG_DOUBLE) */

#if defined(__ia64) && defined(__hpux) && defined(_FPWIDETYPES)

/* NB: _FPWIDETYPES is set by the HP-UX IA-64 compilers in response to
   the -fpwidetypes command-line option */

/* Mimic the HP-UX practice in <float.h>, <math.h>, and <stdlib.h> of
   providing typedefs of the user types extended and quad if they are
   not yet defined. */

#ifndef _INCLUDE_QUAD
typedef __float128 quad;
#define _INCLUDE_QUAD
#endif

#ifndef _INCLUDE_EXTENDED
typedef __float80 extended;
#define _INCLUDE_EXTENDED
#endif

/* enable support for 80-bit extended and 128-bit quad variants of the library */

extern __float80 (acosdegw)(__float80);
extern __float80 (acoshw)(__float80);
extern __float80 (acospiw)(__float80);
extern __float80 (acospw)(__float80);
extern __float80 (acosw)(__float80);
extern __float80 (adxw)(__float80, int);
extern __float80 (agmw)(__float80, __float80);
extern __float80 (annuityw)(__float80, __float80);
extern __float80 (asindegw)(__float80);
extern __float80 (asinhw)(__float80);
extern __float80 (asinpiw)(__float80);
extern __float80 (asinpw)(__float80);
extern __float80 (asinw)(__float80);
extern __float80 (atan2degw)(__float80, __float80);
extern __float80 (atan2pw)(__float80, __float80);
extern __float80 (atan2piw)(__float80, __float80);
extern __float80 (atan2w)(__float80, __float80);
extern __float80 (atandegw)(__float80);
extern __float80 (atanhw)(__float80);
extern __float80 (atanpiw)(__float80);
extern __float80 (atanpw)(__float80);
extern __float80 (atanw)(__float80);
extern __float80 (bis0w)(__float80);
extern __float80 (bernumw)(int);
extern __float80 (betaw)(__float80);
extern __float80 (betam1w)(__float80);
extern __float80 (betnm1w)(int);
extern __float80 (betnumw)(int);
extern __float80 (bi0w)(__float80);
extern __float80 (bis1w)(__float80);
extern __float80 (bi1w)(__float80);
extern __float80 (bisnw)(int, __float80);
extern __float80 (binw)(int, __float80);
extern __float80 (binomw)(int, int);
extern __float80 (bks0w)(__float80);
extern __float80 (bk0w)(__float80);
extern __float80 (bks1w)(__float80);
extern __float80 (bk1w)(__float80);
extern __float80 (bksnw)(int, __float80);
extern __float80 (bknw)(int, __float80);
extern __float80 (cbrtw)(__float80);
extern __float80 (ceilw)(__float80);
extern __float80 (chisqw)(int, __float80);
extern __float80 (compoundw)(__float80, __float80);
extern __float80 (copysignw)(__float80, __float80);
extern __float80 (cosdegw)(__float80);
extern __float80 (coshw)(__float80);
extern __float80 (cospiw)(__float80);
extern __float80 (cospw)(__float80);
extern __float80 (cosw)(__float80);
extern __float80 (cotandegw)(__float80);
extern __float80 (cotanpiw)(__float80);
extern __float80 (cotanpw)(__float80);
extern __float80 (cotanw)(__float80);
extern __float80 (dfactw)(int);
extern __float80 (echebw)(__float80, int, const __float80 []);
extern __float80 (eljaamw)(__float80, __float80);
extern __float80 (eljacdw)(__float80, __float80);
extern __float80 (eljacnw)(__float80, __float80);
extern __float80 (eljacsw)(__float80, __float80);
extern __float80 (eljadcw)(__float80, __float80);
extern __float80 (eljadnw)(__float80, __float80);
extern __float80 (eljadsw)(__float80, __float80);
extern __float80 (eljagw)(__float80, __float80, int, /*@out@*/ __float80 *, /*@out@*/ __float80 *, /*@out@*/ __float80 *, /*@out@*/ __float80 *, /*@out@*/ int *);
extern __float80 (eljamw)(__float80, __float80);
extern __float80 (eljancw)(__float80, __float80);
extern __float80 (eljandw)(__float80, __float80);
extern __float80 (eljansw)(__float80, __float80);
extern __float80 (eljascw)(__float80, __float80);
extern __float80 (eljasdw)(__float80, __float80);
extern __float80 (eljasnw)(__float80, __float80);
extern __float80 (eljcdw)(__float80, __float80);
extern __float80 (eljcnw)(__float80, __float80);
extern __float80 (eljcsw)(__float80, __float80);
extern __float80 (eljdcw)(__float80, __float80);
extern __float80 (eljdnw)(__float80, __float80);
extern __float80 (eljdsw)(__float80, __float80);
extern __float80 (eljhw)(__float80, __float80);
extern void (eljh4w)(/*@out@*/ __float80[], __float80, __float80);
extern __float80 (eljncw)(__float80, __float80);
extern __float80 (eljndw)(__float80, __float80);
extern __float80 (eljnsw)(__float80, __float80);
extern __float80 (eljscw)(__float80, __float80);
extern __float80 (eljsdw)(__float80, __float80);
extern __float80 (eljsnw)(__float80, __float80);
extern __float80 (eljtw)(__float80, __float80);
extern __float80 (eljt1w)(__float80, __float80);
extern __float80 (eljt2w)(__float80, __float80);
extern __float80 (eljt3w)(__float80, __float80);
extern __float80 (eljt4w)(__float80, __float80);
extern void (eljtaw)(/*@out@*/ __float80[], __float80, __float80);
extern __float80 (eljtd1w)(__float80, __float80);
extern __float80 (eljtd2w)(__float80, __float80);
extern __float80 (eljtd3w)(__float80, __float80);
extern __float80 (eljtd4w)(__float80, __float80);
extern void (eljtdaw)(/*@out@*/ __float80 [], __float80, __float80);
extern __float80 (eljzw)(__float80, __float80);
extern __float80 (elkw)(__float80);
extern __float80 (elkm1w)(__float80);
extern __float80 (elldiw)(__float80, __float80);
extern __float80 (ellecw)(__float80);
extern __float80 (ellew)(__float80);
extern __float80 (elleiw)(__float80, __float80);
extern __float80 (ellfiw)(__float80, __float80);
extern __float80 (ellkcw)(__float80);
extern __float80 (ellkw)(__float80);
extern __float80 (ellknw)(__float80);
extern __float80 (ellpiw)(__float80, __float80, __float80);
extern __float80 (ellrcw)(__float80, __float80);
extern __float80 (ellrdw)(__float80, __float80, __float80);
extern __float80 (ellrew)(__float80, __float80);
extern __float80 (ellrfw)(__float80, __float80, __float80);
extern __float80 (ellrgw)(__float80, __float80, __float80);
extern __float80 (ellrhw)(__float80, __float80, __float80, __float80);
extern __float80 (ellrjw)(__float80, __float80, __float80, __float80);
extern __float80 (ellrkw)(__float80, __float80);
extern __float80 (ellrlw)(__float80, __float80, __float80);
extern __float80 (ellrmw)(__float80, __float80, __float80);
extern __float80 (elntcw)(__float80, __float80);
extern __float80 (elntdw)(__float80, __float80);
extern __float80 (elntnw)(__float80, __float80);
extern __float80 (elntsw)(__float80, __float80);
extern __float80 (elqw)(__float80);
extern __float80 (elq1pw)(__float80);
extern __float80 (elqcw)(__float80);
extern __float80 (elqc1pw)(__float80);
extern __float80 (elwdpw)(__float80, __float80, __float80);
extern void (elwew)(/*@null@*/ /*@out@*/ __float80 *, /*@null@*/ /*@out@*/ __float80 *, __float80, __float80);
extern void (elwgw)(/*@null@*/ /*@out@*/ __float80 *, /*@null@*/ /*@out@*/ __float80 *, __float80, __float80);
extern __float80 (elwipw)(__float80, __float80, __float80);
extern void (elwkw)(/*@null@*/ /*@out@*/ __float80 *, /*@null@*/ /*@out@*/ __float80 *, __float80, __float80);
extern void (elwow)(/*@null@*/ /*@out@*/ __float80 *, /*@null@*/ /*@out@*/ __float80 *, __float80, __float80);
extern __float80 (elwpw)(__float80, __float80, __float80);
extern __float80 (elwsw)(__float80, __float80, __float80);
extern __float80 (elwzw)(__float80, __float80, __float80);
extern __float80 (ereducew)(__float80, __float80, int, const __float80 [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ __float80 *, int);
extern __float80 (erfcw)(__float80);
extern __float80 (erfw)(__float80);
extern __float80 (eriducew)(__float80, __float80, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ __float80 *, int);
extern __float80 (eulnumm1w)(int);
extern __float80 (exp10m1w)(__float80);
extern __float80 (exp10w)(__float80);
extern __float80 (exp16m1w)(__float80);
extern __float80 (exp16w)(__float80);
extern __float80 (exp2m1w)(__float80);
extern __float80 (exp2w)(__float80);
extern __float80 (exp8m1w)(__float80);
extern __float80 (exp8w)(__float80);
extern __float80 (expm1w)(__float80);
extern __float80 (expw)(__float80);
extern __float80 (fabsw)(__float80);
extern __float80 (factw)(int);
extern __float80 (fdimw)(__float80, __float80);
extern __float80 (fibnumw)(int);
extern __float80 (floorw)(__float80);
extern __float80 (fmaw)(__float80, __float80, __float80);
extern __float80 (fmaxw)(__float80, __float80);
extern __float80 (fminw)(__float80, __float80);
extern __float80 (fmodw)(__float80, __float80);
extern void (fmulw)(/*@out@*/ __float80 [/* 2 */], __float80, __float80);
extern int (fpclassifyw)(__float80);
extern __float80 (frexphw)(__float80, /*@out@*/ int *);
extern __float80 (frexpow)(__float80, /*@out@*/ int *);
extern __float80 (frexpw)(__float80, /*@out@*/ int *);
extern void (gamibw)(/*@out@*/ __float80[/* 2 */], __float80, __float80);
extern __float80 (gamicw)(__float80, __float80);
extern __float80 (gamiw)(__float80, __float80);
extern __float80 (hypotw)(__float80, __float80);
extern __float80 (ichisqw)(int, __float80);
extern __float80 (ierfcw)(__float80);
extern __float80 (ierfw)(__float80);
extern int (ilogbw)(__float80);
extern __float80 (inftyw)(void);
extern int (intxpw)(__float80);
extern __float80 (iphicw)(__float80);
extern __float80 (iphiw)(__float80);
extern __float80 (ipoww)(__float80, int);
extern int (isfinitew)(__float80);
extern int (isgreaterequalw)(__float80, __float80);
extern int (isgreaterw)(__float80, __float80);
extern int (isinfw)(__float80);
extern int (islessequalw)(__float80, __float80);
extern int (islessgreaterw)(__float80, __float80);
extern int (islessw)(__float80, __float80);
extern int (isnanw)(__float80);
extern int (isnormalw)(__float80);
extern int (isqnanw)(__float80);
extern int (issnanw)(__float80);
extern int (issubnormalw)(__float80);
extern int (isunorderedw)(__float80, __float80);
extern __float80 (j0w)(__float80);
extern __float80 (j1w)(__float80);
extern __float80 (jnw)(int, __float80);
extern __float80 (ldexphw)(__float80, int);
extern __float80 (ldexpow)(__float80, int);
extern __float80 (ldexpw)(__float80, int);
extern __float80 (lgammaw)(__float80);
extern __float80 (lgammaw_r)(__float80, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintw)(__float80);
extern long long int (llroundw)(__float80);
#endif

extern __float80 (log101pw)(__float80);
extern __float80 (log10w)(__float80);
extern __float80 (log161pw)(__float80);
extern __float80 (log16w)(__float80);
extern __float80 (log1pw)(__float80);
extern __float80 (log21pw)(__float80);
extern __float80 (log2w)(__float80);
extern __float80 (log81pw)(__float80);
extern __float80 (log8w)(__float80);
extern __float80 (logbfactw)(int, /*@out@*/ int *);
extern __float80 (logbw)(__float80);
extern __float80 (logw)(__float80);
extern long int (lrintw)(__float80);
extern long int (lroundw)(__float80);
extern __float80 (mchepw)(__float80);
extern __float80 (modfw)(__float80, /*@out@*/ __float80 *);
extern __float80 (nanw)(const char *);
extern __float80 (nearbyintw)(__float80);
extern __float80 (nextafterw)(__float80, __float80);

#if defined(HAVE_LONG_DOUBLE)

extern __float80 (nexttowardw)(__float80, long double);

#endif /* defined(HAVE_LONG_DOUBLE) */

extern __float80 (normalizew)(__float80);
extern const char *(ntosw)(__float80);
extern __float80 (pgammaw)(int, __float80);
extern __float80 (phicw)(__float80);
extern __float80 (phiw)(__float80);
extern __float80 (poww)(__float80, __float80);
extern __float80 (psilnw)(__float80);
extern __float80 (psiw)(__float80);
extern int (qertw)(__float80, __float80, __float80, /*@out@*/ __float80 [/* 2 */], /*@out@*/ __float80 [/* 2 */]);
extern __float80 (qnanw)(const char *);
extern __float80 (quantizew)(__float80, __float80);
extern __float80 (remainderw)(__float80, __float80);
extern __float80 (remquow)(__float80, __float80, /*@out@*/ int *);
extern __float80 (rintw)(__float80);
extern __float80 (roundw)(__float80);
extern __float80 (rsqrtw)(__float80);
extern int (samequantumw)(__float80, __float80);
extern __float80 (sbi0w)(__float80);
extern __float80 (sbi1w)(__float80);
extern __float80 (sbinw)(int, __float80);
extern __float80 (sbis0w)(__float80);
extern __float80 (sbis1w)(__float80);
extern __float80 (sbisnw)(int, __float80);
extern __float80 (sbj0w)(__float80);
extern __float80 (sbj1w)(__float80);
extern __float80 (sbjnw)(int, __float80);
extern __float80 (sbk0w)(__float80);
extern __float80 (sbk1w)(__float80);
extern __float80 (sbknw)(int, __float80);
extern __float80 (sbks0w)(__float80);
extern __float80 (sbks1w)(__float80);
extern __float80 (sbksnw)(int, __float80);
extern __float80 (sby0w)(__float80);
extern __float80 (sby1w)(__float80);
extern __float80 (sbynw)(int, __float80);
extern __float80 (scalblnw)(__float80, long int);
extern __float80 (scalbnw)(__float80, int);
extern __float80 (secondw)(void);
extern __float80 (setxpw)(__float80, int);
extern int (signbitw)(__float80);
extern void (sincospiw)(__float80, /*@out@*/ __float80 *, /*@out@*/ __float80 *);
extern void (sincospw)(__float80, /*@out@*/ __float80 *, /*@out@*/ __float80 *);
extern void (sincosw)(__float80, /*@out@*/ __float80 *, /*@out@*/ __float80 *);
extern __float80 (sindegw)(__float80);
extern void (sinhcoshw)(__float80, /*@out@*/ __float80 *, /*@out@*/ __float80 *);
extern __float80 (sinhw)(__float80);
extern __float80 (sinpiw)(__float80);
extern __float80 (sinpw)(__float80);
extern __float80 (sinw)(__float80);
extern __float80 (snanw)(const char *);
extern __float80 (sqrtw)(__float80);
extern __float80 (tandegw)(__float80);
extern __float80 (tanhw)(__float80);
extern __float80 (tanpiw)(__float80);
extern __float80 (tanpw)(__float80);
extern __float80 (tanw)(__float80);
extern __float80 (tgammaw)(__float80);
extern __float80 (truncw)(__float80);
extern __float80 (ulpkw)(__float80);
extern __float80 (ulpmhw)(__float80);
extern __float80 (vagmw)(__float80, __float80, __float80, int, /*@out@*/ __float80 [], /*@out@*/ __float80 [], /*@out@*/ __float80 [], /*@out@*/ int *);
extern void (vbiw)(int, /*@out@*/ __float80 *, __float80);
extern void (vbisw)(int, /*@out@*/ __float80 *, __float80);
extern void (vbjw)(int, /*@out@*/ __float80 *, __float80);
extern void (vbkw)(int, /*@out@*/ __float80 *, __float80);
extern void (vbksw)(int, /*@out@*/ __float80 *, __float80);
extern void (vbyw)(int, /*@out@*/ __float80 *, __float80);
extern void (_vcopyw)(int, /*@out@*/ __float80 *, __float80 *);
extern void (vsbiw)(int, /*@out@*/ __float80 *, __float80);
extern void (vsbisw)(int, /*@out@*/ __float80 *, __float80);
extern void (vsbjw)(int, /*@out@*/ __float80 *, __float80);
extern void (vsbkw)(int, /*@out@*/ __float80 *, __float80);
extern void (vsbksw)(int, /*@out@*/ __float80 *, __float80);
extern void (vsbyw)(int, /*@out@*/ __float80 *, __float80);
extern void (_vsetw)(int, /*@out@*/ __float80 *, __float80);
extern __float80 (vsumw)(/*@out@*/ __float80 *, int, const __float80 []);
extern __float80 (y0w)(__float80);
extern __float80 (y1w)(__float80);
extern __float80 (ynw)(int, __float80);
extern __float80 (zetaw)(__float80);
extern __float80 (zetam1w)(__float80);
extern __float80 (zetnm1w)(int);
extern __float80 (zetnumw)(int);

extern __float128 (acosdegq)(__float128);
extern __float128 (acoshq)(__float128);
extern __float128 (acospiq)(__float128);
extern __float128 (acospq)(__float128);
extern __float128 (acosq)(__float128);
extern __float128 (adxq)(__float128, int);
extern __float128 (agmq)(__float128, __float128);
extern __float128 (annuityq)(__float128, __float128);
extern __float128 (asindegq)(__float128);
extern __float128 (asinhq)(__float128);
extern __float128 (asinpiq)(__float128);
extern __float128 (asinpq)(__float128);
extern __float128 (asinq)(__float128);
extern __float128 (atan2degq)(__float128, __float128);
extern __float128 (atan2pq)(__float128, __float128);
extern __float128 (atan2piq)(__float128, __float128);
extern __float128 (atan2q)(__float128, __float128);
extern __float128 (atandegq)(__float128);
extern __float128 (atanhq)(__float128);
extern __float128 (atanpiq)(__float128);
extern __float128 (atanpq)(__float128);
extern __float128 (atanq)(__float128);
extern __float128 (bernumq)(int);
extern __float128 (betaq)(__float128);
extern __float128 (betam1q)(__float128);
extern __float128 (betnm1q)(int);
extern __float128 (betnumq)(int);
extern __float128 (bi0q)(__float128);
extern __float128 (bis0q)(__float128);
extern __float128 (bi1q)(__float128);
extern __float128 (bis1q)(__float128);
extern __float128 (binq)(int, __float128);
extern __float128 (binomq)(int, int);
extern __float128 (bisnq)(int, __float128);
extern __float128 (bk0q)(__float128);
extern __float128 (bks0q)(__float128);
extern __float128 (bk1q)(__float128);
extern __float128 (bks1q)(__float128);
extern __float128 (bknq)(int, __float128);
extern __float128 (bksnq)(int, __float128);
extern __float128 (cbrtq)(__float128);
extern __float128 (ceilq)(__float128);
extern __float128 (chisqq)(int, __float128);
extern __float128 (compoundq)(__float128, __float128);
extern __float128 (copysignq)(__float128, __float128);
extern __float128 (cosdegq)(__float128);
extern __float128 (coshq)(__float128);
extern __float128 (cospiq)(__float128);
extern __float128 (cospq)(__float128);
extern __float128 (cosq)(__float128);
extern __float128 (cotandegq)(__float128);
extern __float128 (cotanpiq)(__float128);
extern __float128 (cotanpq)(__float128);
extern __float128 (cotanq)(__float128);
extern __float128 (dfactq)(int);
extern __float128 (echebq)(__float128, int, const __float128 []);
extern __float128 (eljaamq)(__float128, __float128);
extern __float128 (eljacdq)(__float128, __float128);
extern __float128 (eljacnq)(__float128, __float128);
extern __float128 (eljacsq)(__float128, __float128);
extern __float128 (eljadcq)(__float128, __float128);
extern __float128 (eljadnq)(__float128, __float128);
extern __float128 (eljadsq)(__float128, __float128);
extern __float128 (eljagq)(__float128, __float128, int, /*@out@*/ __float128 *, /*@out@*/ __float128 *, /*@out@*/ __float128 *, /*@out@*/ __float128 *, /*@out@*/ int *);
extern __float128 (eljamq)(__float128, __float128);
extern __float128 (eljancq)(__float128, __float128);
extern __float128 (eljandq)(__float128, __float128);
extern __float128 (eljansq)(__float128, __float128);
extern __float128 (eljascq)(__float128, __float128);
extern __float128 (eljasdq)(__float128, __float128);
extern __float128 (eljasnq)(__float128, __float128);
extern __float128 (eljcdq)(__float128, __float128);
extern __float128 (eljcnq)(__float128, __float128);
extern __float128 (eljcsq)(__float128, __float128);
extern __float128 (eljdcq)(__float128, __float128);
extern __float128 (eljdnq)(__float128, __float128);
extern __float128 (eljdsq)(__float128, __float128);
extern __float128 (eljhq)(__float128, __float128);
extern void (eljh4q)(/*@out@*/ __float128[], __float128, __float128);
extern __float128 (eljncq)(__float128, __float128);
extern __float128 (eljndq)(__float128, __float128);
extern __float128 (eljnsq)(__float128, __float128);
extern __float128 (eljscq)(__float128, __float128);
extern __float128 (eljsdq)(__float128, __float128);
extern __float128 (eljsnq)(__float128, __float128);
extern __float128 (eljtq)(__float128, __float128);
extern __float128 (eljt1q)(__float128, __float128);
extern __float128 (eljt2q)(__float128, __float128);
extern __float128 (eljt3q)(__float128, __float128);
extern __float128 (eljt4q)(__float128, __float128);
extern void (eljtaq)(/*@out@*/ __float128[], __float128, __float128);
extern __float128 (eljtd1q)(__float128, __float128);
extern __float128 (eljtd2q)(__float128, __float128);
extern __float128 (eljtd3q)(__float128, __float128);
extern __float128 (eljtd4q)(__float128, __float128);
extern void (eljtdaq)(/*@out@*/ __float128 [], __float128, __float128);
extern __float128 (eljzq)(__float128, __float128);
extern __float128 (elkq)(__float128);
extern __float128 (elkm1q)(__float128);
extern __float128 (elldiq)(__float128, __float128);
extern __float128 (ellecq)(__float128);
extern __float128 (elleq)(__float128);
extern __float128 (elleiq)(__float128, __float128);
extern __float128 (ellfiq)(__float128, __float128);
extern __float128 (ellkcq)(__float128);
extern __float128 (ellkq)(__float128);
extern __float128 (ellknq)(__float128);
extern __float128 (ellpiq)(__float128, __float128, __float128);
extern __float128 (ellrcq)(__float128, __float128);
extern __float128 (ellrdq)(__float128, __float128, __float128);
extern __float128 (ellreq)(__float128, __float128);
extern __float128 (ellrfq)(__float128, __float128, __float128);
extern __float128 (ellrgq)(__float128, __float128, __float128);
extern __float128 (ellrhq)(__float128, __float128, __float128, __float128);
extern __float128 (ellrjq)(__float128, __float128, __float128, __float128);
extern __float128 (ellrkq)(__float128, __float128);
extern __float128 (ellrlq)(__float128, __float128, __float128);
extern __float128 (ellrmq)(__float128, __float128, __float128);
extern __float128 (elntcq)(__float128, __float128);
extern __float128 (elntdq)(__float128, __float128);
extern __float128 (elntnq)(__float128, __float128);
extern __float128 (elntsq)(__float128, __float128);
extern __float128 (elqq)(__float128);
extern __float128 (elq1pq)(__float128);
extern __float128 (elqcq)(__float128);
extern __float128 (elqc1pq)(__float128);
extern __float128 (elwdpq)(__float128, __float128, __float128);
extern void (elweq)(/*@null@*/ /*@out@*/ __float128 *, /*@null@*/ /*@out@*/ __float128 *, __float128, __float128);
extern void (elwgq)(/*@null@*/ /*@out@*/ __float128 *, /*@null@*/ /*@out@*/ __float128 *, __float128, __float128);
extern __float128 (elwipq)(__float128, __float128, __float128);
extern void (elwkq)(/*@null@*/ /*@out@*/ __float128 *, /*@null@*/ /*@out@*/ __float128 *, __float128, __float128);
extern void (elwoq)(/*@null@*/ /*@out@*/ __float128 *, /*@null@*/ /*@out@*/ __float128 *, __float128, __float128);
extern __float128 (elwpq)(__float128, __float128, __float128);
extern __float128 (elwsq)(__float128, __float128, __float128);
extern __float128 (elwzq)(__float128, __float128, __float128);
extern __float128 (ereduceq)(__float128, __float128, int, const __float128 [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ __float128 *, int);
extern __float128 (erfcq)(__float128);
extern __float128 (erfq)(__float128);
extern __float128 (eriduceq)(__float128, __float128, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ __float128 *, int);
extern __float128 (eulnumm1q)(int);
extern __float128 (exp10m1q)(__float128);
extern __float128 (exp10q)(__float128);
extern __float128 (exp16m1q)(__float128);
extern __float128 (exp16q)(__float128);
extern __float128 (exp2m1q)(__float128);
extern __float128 (exp2q)(__float128);
extern __float128 (exp8m1q)(__float128);
extern __float128 (exp8q)(__float128);
extern __float128 (expm1q)(__float128);
extern __float128 (expq)(__float128);
extern __float128 (fabsq)(__float128);
extern __float128 (factq)(int);
extern __float128 (fdimq)(__float128, __float128);
extern __float128 (fibnumq)(int);
extern __float128 (floorq)(__float128);
extern __float128 (fmaq)(__float128, __float128, __float128);
extern __float128 (fmaxq)(__float128, __float128);
extern __float128 (fminq)(__float128, __float128);
extern __float128 (fmodq)(__float128, __float128);
extern void (fmulq)(/*@out@*/ __float128 [/* 2 */], __float128, __float128);
extern int (fpclassifyq)(__float128);
extern __float128 (frexphq)(__float128, /*@out@*/ int *);
extern __float128 (frexpoq)(__float128, /*@out@*/ int *);
extern __float128 (frexpq)(__float128, /*@out@*/ int *);
extern void (gamibq)(/*@out@*/ __float128[/* 2 */], __float128, __float128);
extern __float128 (gamicq)(__float128, __float128);
extern __float128 (gamiq)(__float128, __float128);
extern __float128 (hypotq)(__float128, __float128);
extern __float128 (ichisqq)(int, __float128);
extern __float128 (ierfcq)(__float128);
extern __float128 (ierfq)(__float128);
extern int (ilogbq)(__float128);
extern __float128 (inftyq)(void);
extern int (intxpq)(__float128);
extern __float128 (iphicq)(__float128);
extern __float128 (iphiq)(__float128);
extern __float128 (ipowq)(__float128, int);
extern int (isfiniteq)(__float128);
extern int (isgreaterequalq)(__float128, __float128);
extern int (isgreaterq)(__float128, __float128);
extern int (isinfq)(__float128);
extern int (islessequalq)(__float128, __float128);
extern int (islessgreaterq)(__float128, __float128);
extern int (islessq)(__float128, __float128);
extern int (isnanq)(__float128);
extern int (isnormalq)(__float128);
extern int (isqnanq)(__float128);
extern int (issnanq)(__float128);
extern int (issubnormalq)(__float128);
extern int (isunorderedq)(__float128, __float128);
extern __float128 (j0q)(__float128);
extern __float128 (j1q)(__float128);
extern __float128 (jnq)(int, __float128);
extern __float128 (ldexphq)(__float128, int);
extern __float128 (ldexpoq)(__float128, int);
extern __float128 (ldexpq)(__float128, int);
extern __float128 (lgammaq)(__float128);
extern __float128 (lgammaq_r)(__float128, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintq)(__float128);
extern long long int (llroundq)(__float128);
#endif

extern __float128 (log101pq)(__float128);
extern __float128 (log10q)(__float128);
extern __float128 (log161pq)(__float128);
extern __float128 (log16q)(__float128);
extern __float128 (log1pq)(__float128);
extern __float128 (log21pq)(__float128);
extern __float128 (log2q)(__float128);
extern __float128 (log81pq)(__float128);
extern __float128 (log8q)(__float128);
extern __float128 (logbfactq)(int, /*@out@*/ int *);
extern __float128 (logbq)(__float128);
extern __float128 (logq)(__float128);
extern long int (lrintq)(__float128);
extern long int (lroundq)(__float128);
extern __float128 (mchepq)(__float128);
extern __float128 (modfq)(__float128, /*@out@*/ __float128 *);
extern __float128 (nanq)(const char *);
extern __float128 (nearbyintq)(__float128);
extern __float128 (nextafterq)(__float128, __float128);

#if defined(HAVE_LONG_DOUBLE)

extern __float128 (nexttowardq)(__float128, long double);

#endif /* defined(HAVE_LONG_DOUBLE) */

extern __float128 (normalizeq)(__float128);
extern const char *(ntosq)(__float128);
extern __float128 (pgammaq)(int, __float128);
extern __float128 (phicq)(__float128);
extern __float128 (phiq)(__float128);
extern __float128 (powq)(__float128, __float128);
extern __float128 (psilnq)(__float128);
extern __float128 (psiq)(__float128);
extern int (qertq)(__float128, __float128, __float128, /*@out@*/ __float128 [/* 2 */], /*@out@*/ __float128 [/* 2 */]);
extern __float128 (qnanq)(const char *);
extern __float128 (quantizeq)(__float128, __float128);
extern __float128 (remainderq)(__float128, __float128);
extern __float128 (remquoq)(__float128, __float128, /*@out@*/ int *);
extern __float128 (rintq)(__float128);
extern __float128 (roundq)(__float128);
extern __float128 (rsqrtq)(__float128);
extern int (samequantumq)(__float128, __float128);
extern __float128 (sbi0q)(__float128);
extern __float128 (sbi1q)(__float128);
extern __float128 (sbinq)(int, __float128);
extern __float128 (sbis0q)(__float128);
extern __float128 (sbis1q)(__float128);
extern __float128 (sbisnq)(int, __float128);
extern __float128 (sbj0q)(__float128);
extern __float128 (sbj1q)(__float128);
extern __float128 (sbjnq)(int, __float128);
extern __float128 (sbk0q)(__float128);
extern __float128 (sbk1q)(__float128);
extern __float128 (sbknq)(int, __float128);
extern __float128 (sbks0q)(__float128);
extern __float128 (sbks1q)(__float128);
extern __float128 (sbksnq)(int, __float128);
extern __float128 (sby0q)(__float128);
extern __float128 (sby1q)(__float128);
extern __float128 (sbynq)(int, __float128);
extern __float128 (scalblnq)(__float128, long int);
extern __float128 (scalbnq)(__float128, int);
extern __float128 (secondq)(void);
extern __float128 (setxpq)(__float128, int);
extern int (signbitq)(__float128);
extern void (sincospiq)(__float128, /*@out@*/ __float128 *, /*@out@*/ __float128 *);
extern void (sincospq)(__float128, /*@out@*/ __float128 *, /*@out@*/ __float128 *);
extern void (sincosq)(__float128, /*@out@*/ __float128 *, /*@out@*/ __float128 *);
extern __float128 (sindegq)(__float128);
extern void (sinhcoshq)(__float128, /*@out@*/ __float128 *, /*@out@*/ __float128 *);
extern __float128 (sinhq)(__float128);
extern __float128 (sinpiq)(__float128);
extern __float128 (sinpq)(__float128);
extern __float128 (sinq)(__float128);
extern __float128 (snanq)(const char *);
extern __float128 (sqrtq)(__float128);
extern __float128 (tandegq)(__float128);
extern __float128 (tanhq)(__float128);
extern __float128 (tanpiq)(__float128);
extern __float128 (tanpq)(__float128);
extern __float128 (tanq)(__float128);
extern __float128 (tgammaq)(__float128);
extern __float128 (truncq)(__float128);
extern __float128 (ulpkq)(__float128);
extern __float128 (ulpmhq)(__float128);
extern __float128 (vagmq)(__float128, __float128, __float128, int, /*@out@*/ __float128 [], /*@out@*/ __float128 [], /*@out@*/ __float128 [], /*@out@*/ int *);
extern void (vbiq)(int, /*@out@*/ __float128 *, __float128);
extern void (vbisq)(int, /*@out@*/ __float128 *, __float128);
extern void (vbjq)(int, /*@out@*/ __float128 *, __float128);
extern void (vbkq)(int, /*@out@*/ __float128 *, __float128);
extern void (vbksq)(int, /*@out@*/ __float128 *, __float128);
extern void (_vcopyq)(int, /*@out@*/ __float128 *, __float128 *);
extern void (vbyq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbiq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbisq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbjq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbkq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbksq)(int, /*@out@*/ __float128 *, __float128);
extern void (vsbyq)(int, /*@out@*/ __float128 *, __float128);
extern void (_vsetq)(int, /*@out@*/ __float128 *, __float128);
extern __float128 (vsumq)(/*@out@*/ __float128 *, int, const __float128 []);
extern __float128 (y0q)(__float128);
extern __float128 (y1q)(__float128);
extern __float128 (ynq)(int, __float128);
extern __float128 (zetaq)(__float128);
extern __float128 (zetam1q)(__float128);
extern __float128 (zetnm1q)(int);
extern __float128 (zetnumq)(int);

#endif /* defined(__ia64) && defined(__hpux) && defined(_FPWIDETYPES) */

#if defined(HAVE_DECIMAL)

extern decimal_float (acosdegdf)(decimal_float);
extern decimal_float (acosdf)(decimal_float);
extern decimal_float (acoshdf)(decimal_float);
extern decimal_float (acospdf)(decimal_float);
extern decimal_float (acospidf)(decimal_float);
extern decimal_float (adxdf)(decimal_float, int);
extern decimal_float (agmdf)(decimal_float, decimal_float);
extern decimal_float (annuitydf)(decimal_float, decimal_float);
extern decimal_float (asindegdf)(decimal_float);
extern decimal_float (asindf)(decimal_float);
extern decimal_float (asinhdf)(decimal_float);
extern decimal_float (asinpdf)(decimal_float);
extern decimal_float (asinpidf)(decimal_float);
extern decimal_float (atan2degdf)(decimal_float, decimal_float);
extern decimal_float (atan2df)(decimal_float, decimal_float);
extern decimal_float (atan2pdf)(decimal_float, decimal_float);
extern decimal_float (atan2pidf)(decimal_float, decimal_float);
extern decimal_float (atandegdf)(decimal_float);
extern decimal_float (atandf)(decimal_float);
extern decimal_float (atanhdf)(decimal_float);
extern decimal_float (atanpdf)(decimal_float);
extern decimal_float (atanpidf)(decimal_float);
extern decimal_float (bernumdf)(int);
extern decimal_float (betadf)(decimal_float);
extern decimal_float (betam1df)(decimal_float);
extern decimal_float (betnm1df)(int);
extern decimal_float (betnumdf)(int);
extern decimal_float (bi0df)(decimal_float);
extern decimal_float (bis0df)(decimal_float);
extern decimal_float (bi1df)(decimal_float);
extern decimal_float (bis1df)(decimal_float);
extern decimal_float (bindf)(int, decimal_float);
extern decimal_float (binomdf)(int, int);
extern decimal_float (bisndf)(int, decimal_float);
extern decimal_float (bk0df)(decimal_float);
extern decimal_float (bks0df)(decimal_float);
extern decimal_float (bk1df)(decimal_float);
extern decimal_float (bks1df)(decimal_float);
extern decimal_float (bkndf)(int, decimal_float);
extern decimal_float (bksndf)(int, decimal_float);
extern decimal_float (cbrtdf)(decimal_float);
extern decimal_float (ceildf)(decimal_float);
extern decimal_float (chisqdf)(int, decimal_float);
extern decimal_float (compounddf)(decimal_float, decimal_float);
extern decimal_float (copysigndf)(decimal_float, decimal_float);
extern decimal_float (cosdegdf)(decimal_float);
extern decimal_float (cosdf)(decimal_float);
extern decimal_float (coshdf)(decimal_float);
extern decimal_float (cospdf)(decimal_float);
extern decimal_float (cospidf)(decimal_float);
extern decimal_float (cotandegdf)(decimal_float);
extern decimal_float (cotandf)(decimal_float);
extern decimal_float (cotanpdf)(decimal_float);
extern decimal_float (cotanpidf)(decimal_float);
extern decimal_float (dfactdf)(int);
extern decimal_float (echebdf)(decimal_float, int, const decimal_float []);
extern decimal_float (eljaamdf)(decimal_float, decimal_float);
extern decimal_float (eljacddf)(decimal_float, decimal_float);
extern decimal_float (eljacndf)(decimal_float, decimal_float);
extern decimal_float (eljacsdf)(decimal_float, decimal_float);
extern decimal_float (eljadcdf)(decimal_float, decimal_float);
extern decimal_float (eljadndf)(decimal_float, decimal_float);
extern decimal_float (eljadsdf)(decimal_float, decimal_float);
extern decimal_float (eljagdf)(decimal_float, decimal_float, int, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *, /*@out@*/ int *);
extern decimal_float (eljamdf)(decimal_float, decimal_float);
extern decimal_float (eljancdf)(decimal_float, decimal_float);
extern decimal_float (eljanddf)(decimal_float, decimal_float);
extern decimal_float (eljansdf)(decimal_float, decimal_float);
extern decimal_float (eljascdf)(decimal_float, decimal_float);
extern decimal_float (eljasddf)(decimal_float, decimal_float);
extern decimal_float (eljasndf)(decimal_float, decimal_float);
extern decimal_float (eljcddf)(decimal_float, decimal_float);
extern decimal_float (eljcndf)(decimal_float, decimal_float);
extern decimal_float (eljcsdf)(decimal_float, decimal_float);
extern decimal_float (eljdcdf)(decimal_float, decimal_float);
extern decimal_float (eljdndf)(decimal_float, decimal_float);
extern decimal_float (eljdsdf)(decimal_float, decimal_float);
extern decimal_float (eljhdf)(decimal_float, decimal_float);
extern void (eljh4df)(/*@out@*/ decimal_float[], decimal_float, decimal_float);
extern decimal_float (eljncdf)(decimal_float, decimal_float);
extern decimal_float (eljnddf)(decimal_float, decimal_float);
extern decimal_float (eljnsdf)(decimal_float, decimal_float);
extern decimal_float (eljscdf)(decimal_float, decimal_float);
extern decimal_float (eljsddf)(decimal_float, decimal_float);
extern decimal_float (eljsndf)(decimal_float, decimal_float);
extern decimal_float (eljtdf)(decimal_float, decimal_float);
extern decimal_float (eljt1df)(decimal_float, decimal_float);
extern decimal_float (eljt2df)(decimal_float, decimal_float);
extern decimal_float (eljt3df)(decimal_float, decimal_float);
extern decimal_float (eljt4df)(decimal_float, decimal_float);
extern void (eljtadf)(/*@out@*/ decimal_float[], decimal_float, decimal_float);
extern decimal_float (eljtd1df)(decimal_float, decimal_float);
extern decimal_float (eljtd2df)(decimal_float, decimal_float);
extern decimal_float (eljtd3df)(decimal_float, decimal_float);
extern decimal_float (eljtd4df)(decimal_float, decimal_float);
extern void (eljtdadf)(/*@out@*/ decimal_float [], decimal_float, decimal_float);
extern decimal_float (eljzdf)(decimal_float, decimal_float);
extern decimal_float (elkdf)(decimal_float);
extern decimal_float (elkm1df)(decimal_float);
extern decimal_float (elldidf)(decimal_float, decimal_float);
extern decimal_float (ellecdf)(decimal_float);
extern decimal_float (elledf)(decimal_float);
extern decimal_float (elleidf)(decimal_float, decimal_float);
extern decimal_float (ellfidf)(decimal_float, decimal_float);
extern decimal_float (ellkcdf)(decimal_float);
extern decimal_float (ellkdf)(decimal_float);
extern decimal_float (ellkndf)(decimal_float);
extern decimal_float (ellpidf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrcdf)(decimal_float, decimal_float);
extern decimal_float (ellrddf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ellredf)(decimal_float, decimal_float);
extern decimal_float (ellrfdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrgdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrhdf)(decimal_float, decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrjdf)(decimal_float, decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrkdf)(decimal_float, decimal_float);
extern decimal_float (ellrldf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ellrmdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (elntcdf)(decimal_float, decimal_float);
extern decimal_float (elntddf)(decimal_float, decimal_float);
extern decimal_float (elntndf)(decimal_float, decimal_float);
extern decimal_float (elntsdf)(decimal_float, decimal_float);
extern decimal_float (elqdf)(decimal_float);
extern decimal_float (elq1pdf)(decimal_float);
extern decimal_float (elqcdf)(decimal_float);
extern decimal_float (elqc1pdf)(decimal_float);
extern decimal_float (elwdpdf)(decimal_float, decimal_float, decimal_float);
extern void (elwedf)(/*@null@*/ /*@out@*/ decimal_float *, /*@null@*/ /*@out@*/ decimal_float *, decimal_float, decimal_float);
extern void (elwgdf)(/*@null@*/ /*@out@*/ decimal_float *, /*@null@*/ /*@out@*/ decimal_float *, decimal_float, decimal_float);
extern decimal_float (elwipdf)(decimal_float, decimal_float, decimal_float);
extern void (elwkdf)(/*@null@*/ /*@out@*/ decimal_float *, /*@null@*/ /*@out@*/ decimal_float *, decimal_float, decimal_float);
extern void (elwodf)(/*@null@*/ /*@out@*/ decimal_float *, /*@null@*/ /*@out@*/ decimal_float *, decimal_float, decimal_float);
extern decimal_float (elwpdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (elwsdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (elwzdf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (ereducedf)(decimal_float, decimal_float, int, const decimal_float [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_float *, int);
extern decimal_float (erfcdf)(decimal_float);
extern decimal_float (erfdf)(decimal_float);
extern decimal_float (eriducedf)(decimal_float, decimal_float, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_float *, int);
extern decimal_float (eulnumdf)(int);
extern decimal_float (exp10df)(decimal_float);
extern decimal_float (exp10m1df)(decimal_float);
extern decimal_float (exp16df)(decimal_float);
extern decimal_float (exp16m1df)(decimal_float);
extern decimal_float (exp2df)(decimal_float);
extern decimal_float (exp2m1df)(decimal_float);
extern decimal_float (exp8df)(decimal_float);
extern decimal_float (exp8m1df)(decimal_float);
extern decimal_float (expdf)(decimal_float);
extern decimal_float (expm1df)(decimal_float);
extern decimal_float (fabsdf)(decimal_float);
extern decimal_float (factdf)(int);
extern decimal_float (fdimdf)(decimal_float, decimal_float);
extern decimal_float (fibnumdf)(int);
extern decimal_float (floordf)(decimal_float);
extern decimal_float (fmadf)(decimal_float, decimal_float, decimal_float);
extern decimal_float (fmaxdf)(decimal_float, decimal_float);
extern decimal_float (fmindf)(decimal_float, decimal_float);
extern decimal_float (fmoddf)(decimal_float, decimal_float);
extern void (fmuldf)(/*@out@*/ decimal_float [/* 2 */], decimal_float, decimal_float);
extern int (fpclassifydf)(decimal_float);
extern decimal_float (frexpdf)(decimal_float, /*@out@*/ int *);
extern decimal_float (frexphdf)(decimal_float, /*@out@*/ int *);
extern decimal_float (frexpodf)(decimal_float, /*@out@*/ int *);
extern void (gamibdf)(/*@out@*/ decimal_float[/* 2 */], decimal_float, decimal_float);
extern decimal_float (gamicdf)(decimal_float, decimal_float);
extern decimal_float (gamidf)(decimal_float, decimal_float);
extern decimal_float (hypotdf)(decimal_float, decimal_float);
extern decimal_float (ichisqdf)(int, decimal_float);
extern decimal_float (ierfcdf)(decimal_float);
extern decimal_float (ierfdf)(decimal_float);
extern int (ilogbdf)(decimal_float);
extern decimal_float (inftydf)(void);
extern int (intxpdf)(decimal_float);
extern decimal_float (iphicdf)(decimal_float);
extern decimal_float (iphidf)(decimal_float);
extern decimal_float (ipowdf)(decimal_float, int);
extern int (isfinitedf)(decimal_float);
extern int (isgreaterdf)(decimal_float, decimal_float);
extern int (isgreaterequaldf)(decimal_float, decimal_float);
extern int (isinfdf)(decimal_float);
extern int (islessdf)(decimal_float, decimal_float);
extern int (islessequaldf)(decimal_float, decimal_float);
extern int (islessgreaterdf)(decimal_float, decimal_float);
extern int (isnandf)(decimal_float);
extern int (isnormaldf)(decimal_float);
extern int (isqnandf)(decimal_float);
extern int (issnandf)(decimal_float);
extern int (issubnormaldf)(decimal_float);
extern int (isunordereddf)(decimal_float, decimal_float);
extern decimal_float (j0df)(decimal_float);
extern decimal_float (j1df)(decimal_float);
extern decimal_float (jndf)(int, decimal_float);
extern decimal_float (ldexpdf)(decimal_float, int);
extern decimal_float (ldexphdf)(decimal_float, int);
extern decimal_float (ldexpodf)(decimal_float, int);
extern decimal_float (lgammadf)(decimal_float);
extern decimal_float (lgammadf_r)(decimal_float, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintdf)(decimal_float);
extern long long int (llrounddf)(decimal_float);
#endif

extern decimal_float (log101pdf)(decimal_float);
extern decimal_float (log10df)(decimal_float);
extern decimal_float (log161pdf)(decimal_float);
extern decimal_float (log16df)(decimal_float);
extern decimal_float (log1pdf)(decimal_float);
extern decimal_float (log21pdf)(decimal_float);
extern decimal_float (log2df)(decimal_float);
extern decimal_float (log81pdf)(decimal_float);
extern decimal_float (log8df)(decimal_float);
extern decimal_float (logbfactdf)(int, /*@out@*/ int *);
extern decimal_float (logbdf)(decimal_float);
extern decimal_float (logdf)(decimal_float);
extern long int (lrintdf)(decimal_float);
extern long int (lrounddf)(decimal_float);
extern decimal_float (mchepdf)(decimal_float);
extern decimal_float (modfdf)(decimal_float, /*@out@*/ decimal_float *);
extern decimal_float (nandf)(const char *);
extern decimal_float (nearbyintdf)(decimal_float);
extern decimal_float (nextafterdf)(decimal_float, decimal_float);

#if defined(HAVE_DECIMAL_LONG_DOUBLE)

extern decimal_float (nexttowarddf)(decimal_float, decimal_long_double);

#endif /* defined(HAVE_DECIMAL_LONG_DOUBLE) */

extern decimal_float (normalizedf)(decimal_float);
extern const char   *(ntosdf)(decimal_float);
extern decimal_float (pgammadf)(int, decimal_float);
extern decimal_float (phicdf)(decimal_float);
extern decimal_float (phidf)(decimal_float);
extern decimal_float (powdf)(decimal_float, decimal_float);
extern decimal_float (psidf)(decimal_float);
extern decimal_float (psilndf)(decimal_float);
extern int (qertdf)(decimal_float, decimal_float, decimal_float, /*@out@*/ decimal_float [/* 2 */], /*@out@*/ decimal_float [/* 2 */]);
extern decimal_float (qnandf)(const char *);
extern decimal_float (quantizedf)(decimal_float, decimal_float);
extern decimal_float (remainderdf)(decimal_float, decimal_float);
extern decimal_float (remquodf)(decimal_float, decimal_float, /*@out@*/ int *);
extern decimal_float (rintdf)(decimal_float);
extern decimal_float (rounddf)(decimal_float);
extern decimal_float (rsqrtdf)(decimal_float);
extern int (samequantumdf)(decimal_float, decimal_float);
extern decimal_float (sbi0df)(decimal_float);
extern decimal_float (sbi1df)(decimal_float);
extern decimal_float (sbindf)(int, decimal_float);
extern decimal_float (sbis0df)(decimal_float);
extern decimal_float (sbis1df)(decimal_float);
extern decimal_float (sbisndf)(int, decimal_float);
extern decimal_float (sbj0df)(decimal_float);
extern decimal_float (sbj1df)(decimal_float);
extern decimal_float (sbjndf)(int, decimal_float);
extern decimal_float (sbk0df)(decimal_float);
extern decimal_float (sbk1df)(decimal_float);
extern decimal_float (sbkndf)(int, decimal_float);
extern decimal_float (sbks0df)(decimal_float);
extern decimal_float (sbks1df)(decimal_float);
extern decimal_float (sbksndf)(int, decimal_float);
extern decimal_float (sby0df)(decimal_float);
extern decimal_float (sby1df)(decimal_float);
extern decimal_float (sbyndf)(int, decimal_float);
extern decimal_float (scalblndf)(decimal_float, long int);
extern decimal_float (scalbndf)(decimal_float, int);
extern decimal_float (seconddf)(void);
extern decimal_float (setxpdf)(decimal_float, int);
extern int (signbitdf)(decimal_float);
extern void (sincosdf)(decimal_float, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *);
extern void (sincospdf)(decimal_float, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *);
extern void (sincospidf)(decimal_float, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *);
extern decimal_float (sindegdf)(decimal_float);
extern decimal_float (sindf)(decimal_float);
extern void (sinhcoshdf)(decimal_float, /*@out@*/ decimal_float *, /*@out@*/ decimal_float *);
extern decimal_float (sinhdf)(decimal_float);
extern decimal_float (sinpdf)(decimal_float);
extern decimal_float (sinpidf)(decimal_float);
extern decimal_float (snandf)(const char *);
extern decimal_float (sqrtdf)(decimal_float);
extern decimal_float (strtoddf)(const char *, char **);
extern decimal_float (tandegdf)(decimal_float);
extern decimal_float (tandf)(decimal_float);
extern decimal_float (tanhdf)(decimal_float);
extern decimal_float (tanpdf)(decimal_float);
extern decimal_float (tanpidf)(decimal_float);
extern decimal_float (tgammadf)(decimal_float);
extern decimal_float (truncdf)(decimal_float);
extern decimal_float (ulpkdf)(decimal_double);
extern decimal_float (ulpmhdf)(decimal_double);
extern decimal_float (vagmdf)(decimal_float, decimal_float, decimal_float, int, /*@out@*/ decimal_float [], /*@out@*/ decimal_float [], /*@out@*/ decimal_float [], /*@out@*/ int *);
extern void (vbidf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vbisdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vbjdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vbkdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vbksdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vbydf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (_vcopydf)(int, /*@out@*/ decimal_float *, decimal_float *);
extern void (vsbidf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vsbisdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vsbjdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vsbkdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vsbksdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (vsbydf)(int, /*@out@*/ decimal_float *, decimal_float);
extern void (_vsetdf)(int, /*@out@*/ decimal_float *, decimal_float);
extern decimal_float (vsumdf)(/*@out@*/ decimal_float *, int, const decimal_float []);
extern decimal_float (y0df)(decimal_float);
extern decimal_float (y1df)(decimal_float);
extern decimal_float (yndf)(int, decimal_float);
extern decimal_float (zetadf)(decimal_float);
extern decimal_float (zetam1df)(decimal_float);
extern decimal_float (zetnm1df)(int);
extern decimal_float (zetnumdf)(int);

extern decimal_double (acosd)(decimal_double);
extern decimal_double (acosdegd)(decimal_double);
extern decimal_double (acoshd)(decimal_double);
extern decimal_double (acospd)(decimal_double);
extern decimal_double (acospid)(decimal_double);
extern decimal_double (adxd)(decimal_double, int);
extern decimal_double (agmd)(decimal_double, decimal_double);
extern decimal_double (annuityd)(decimal_double, decimal_double);
extern decimal_double (asind)(decimal_double);
extern decimal_double (asindegd)(decimal_double);
extern decimal_double (asinhd)(decimal_double);
extern decimal_double (asinpd)(decimal_double);
extern decimal_double (asinpid)(decimal_double);
extern decimal_double (atan2d)(decimal_double, decimal_double);
extern decimal_double (atan2degd)(decimal_double, decimal_double);
extern decimal_double (atan2pd)(decimal_double, decimal_double);
extern decimal_double (atan2pid)(decimal_double, decimal_double);
extern decimal_double (atand)(decimal_double);
extern decimal_double (atandegd)(decimal_double);
extern decimal_double (atanhd)(decimal_double);
extern decimal_double (atanpd)(decimal_double);
extern decimal_double (atanpid)(decimal_double);
extern decimal_double (bernumd)(int);
extern decimal_double (betad)(decimal_double);
extern decimal_double (betam1d)(decimal_double);
extern decimal_double (betnm1d)(int);
extern decimal_double (betnumd)(int);
extern decimal_double (bi0d)(decimal_double);
extern decimal_double (bis0d)(decimal_double);
extern decimal_double (bi1d)(decimal_double);
extern decimal_double (bis1d)(decimal_double);
extern decimal_double (bind)(int, decimal_double);
extern decimal_double (binomd)(int, int);
extern decimal_double (bisnd)(int, decimal_double);
extern decimal_double (bk0d)(decimal_double);
extern decimal_double (bks0d)(decimal_double);
extern decimal_double (bk1d)(decimal_double);
extern decimal_double (bks1d)(decimal_double);
extern decimal_double (bknd)(int, decimal_double);
extern decimal_double (bksnd)(int, decimal_double);
extern decimal_double (cbrtd)(decimal_double);
extern decimal_double (ceild)(decimal_double);
extern decimal_double (chisqd)(int, decimal_double);
extern decimal_double (compoundd)(decimal_double, decimal_double);
extern decimal_double (copysignd)(decimal_double, decimal_double);
extern decimal_double (cosd)(decimal_double);
extern decimal_double (cosdegd)(decimal_double);
extern decimal_double (coshd)(decimal_double);
extern decimal_double (cospd)(decimal_double);
extern decimal_double (cospid)(decimal_double);
extern decimal_double (cotand)(decimal_double);
extern decimal_double (cotandegd)(decimal_double);
extern decimal_double (cotanpd)(decimal_double);
extern decimal_double (cotanpid)(decimal_double);
extern decimal_double (dfactd)(int);
extern decimal_double (echebd)(decimal_double, int, const decimal_double []);
extern decimal_double (eljaamd)(decimal_double, decimal_double);
extern decimal_double (eljacdd)(decimal_double, decimal_double);
extern decimal_double (eljacnd)(decimal_double, decimal_double);
extern decimal_double (eljacsd)(decimal_double, decimal_double);
extern decimal_double (eljadcd)(decimal_double, decimal_double);
extern decimal_double (eljadnd)(decimal_double, decimal_double);
extern decimal_double (eljadsd)(decimal_double, decimal_double);
extern decimal_double (eljagd)(decimal_double, decimal_double, int, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *, /*@out@*/ int *);
extern decimal_double (eljamd)(decimal_double, decimal_double);
extern decimal_double (eljancd)(decimal_double, decimal_double);
extern decimal_double (eljandd)(decimal_double, decimal_double);
extern decimal_double (eljansd)(decimal_double, decimal_double);
extern decimal_double (eljascd)(decimal_double, decimal_double);
extern decimal_double (eljasdd)(decimal_double, decimal_double);
extern decimal_double (eljasnd)(decimal_double, decimal_double);
extern decimal_double (eljcdd)(decimal_double, decimal_double);
extern decimal_double (eljcnd)(decimal_double, decimal_double);
extern decimal_double (eljcsd)(decimal_double, decimal_double);
extern decimal_double (eljdcd)(decimal_double, decimal_double);
extern decimal_double (eljdnd)(decimal_double, decimal_double);
extern decimal_double (eljdsd)(decimal_double, decimal_double);
extern decimal_double (eljhd)(decimal_double, decimal_double);
extern void (eljh4d)(/*@out@*/ decimal_double[], decimal_double, decimal_double);
extern decimal_double (eljncd)(decimal_double, decimal_double);
extern decimal_double (eljndd)(decimal_double, decimal_double);
extern decimal_double (eljnsd)(decimal_double, decimal_double);
extern decimal_double (eljscd)(decimal_double, decimal_double);
extern decimal_double (eljsdd)(decimal_double, decimal_double);
extern decimal_double (eljsnd)(decimal_double, decimal_double);
extern decimal_double (eljtd)(decimal_double, decimal_double);
extern decimal_double (eljt1d)(decimal_double, decimal_double);
extern decimal_double (eljt2d)(decimal_double, decimal_double);
extern decimal_double (eljt3d)(decimal_double, decimal_double);
extern decimal_double (eljt4d)(decimal_double, decimal_double);
extern void (eljtad)(/*@out@*/ decimal_double[], decimal_double, decimal_double);
extern decimal_double (eljtd1d)(decimal_double, decimal_double);
extern decimal_double (eljtd2d)(decimal_double, decimal_double);
extern decimal_double (eljtd3d)(decimal_double, decimal_double);
extern decimal_double (eljtd4d)(decimal_double, decimal_double);
extern void (eljtdad)(/*@out@*/ decimal_double [], decimal_double, decimal_double);
extern decimal_double (eljzd)(decimal_double, decimal_double);
extern decimal_double (elkd)(decimal_double);
extern decimal_double (elkm1d)(decimal_double);
extern decimal_double (elldid)(decimal_double, decimal_double);
extern decimal_double (ellecd)(decimal_double);
extern decimal_double (elled)(decimal_double);
extern decimal_double (elleid)(decimal_double, decimal_double);
extern decimal_double (ellfid)(decimal_double, decimal_double);
extern decimal_double (ellkcd)(decimal_double);
extern decimal_double (ellkd)(decimal_double);
extern decimal_double (ellknd)(decimal_double);
extern decimal_double (ellpid)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrcd)(decimal_double, decimal_double);
extern decimal_double (ellrdd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ellred)(decimal_double, decimal_double);
extern decimal_double (ellrfd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrgd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrhd)(decimal_double, decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrjd)(decimal_double, decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrkd)(decimal_double, decimal_double);
extern decimal_double (ellrld)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ellrmd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (elntcd)(decimal_double, decimal_double);
extern decimal_double (elntdd)(decimal_double, decimal_double);
extern decimal_double (elntnd)(decimal_double, decimal_double);
extern decimal_double (elntsd)(decimal_double, decimal_double);
extern decimal_double (elqd)(decimal_double);
extern decimal_double (elq1pd)(decimal_double);
extern decimal_double (elqcd)(decimal_double);
extern decimal_double (elqc1pd)(decimal_double);
extern decimal_double (elwdpd)(decimal_double, decimal_double, decimal_double);
extern void (elwed)(/*@null@*/ /*@out@*/ decimal_double *, /*@null@*/ /*@out@*/ decimal_double *, decimal_double, decimal_double);
extern void (elwgd)(/*@null@*/ /*@out@*/ decimal_double *, /*@null@*/ /*@out@*/ decimal_double *, decimal_double, decimal_double);
extern decimal_double (elwipd)(decimal_double, decimal_double, decimal_double);
extern void (elwkd)(/*@null@*/ /*@out@*/ decimal_double *, /*@null@*/ /*@out@*/ decimal_double *, decimal_double, decimal_double);
extern void (elwod)(/*@null@*/ /*@out@*/ decimal_double *, /*@null@*/ /*@out@*/ decimal_double *, decimal_double, decimal_double);
extern decimal_double (elwpd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (elwsd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (elwzd)(decimal_double, decimal_double, decimal_double);
extern decimal_double (ereduced)(decimal_double, decimal_double, int, const decimal_double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_double *, int);
extern decimal_double (erfcd)(decimal_double);
extern decimal_double (erfd)(decimal_double);
extern decimal_double (eriduced)(decimal_double, decimal_double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_double *, int);
extern decimal_double (eulnumd)(int);
extern decimal_double (exp10d)(decimal_double);
extern decimal_double (exp10m1d)(decimal_double);
extern decimal_double (exp16d)(decimal_double);
extern decimal_double (exp16m1d)(decimal_double);
extern decimal_double (exp2d)(decimal_double);
extern decimal_double (exp2m1d)(decimal_double);
extern decimal_double (exp8d)(decimal_double);
extern decimal_double (exp8m1d)(decimal_double);
extern decimal_double (expd)(decimal_double);
extern decimal_double (expm1d)(decimal_double);
extern decimal_double (fabsd)(decimal_double);
extern decimal_double (factd)(int);
extern decimal_double (fdimd)(decimal_double, decimal_double);
extern decimal_double (fibnumd)(int);
extern decimal_double (floord)(decimal_double);
extern decimal_double (fmad)(decimal_double, decimal_double, decimal_double);
extern decimal_double (fmaxd)(decimal_double, decimal_double);
extern decimal_double (fmind)(decimal_double, decimal_double);
extern decimal_double (fmodd)(decimal_double, decimal_double);
extern void (fmuld)(/*@out@*/ decimal_double [/* 2 */], decimal_double, decimal_double);
extern int (fpclassifyd)(decimal_double);
extern decimal_double (frexpd)(decimal_double, /*@out@*/ int *);
extern decimal_double (frexphd)(decimal_double, /*@out@*/ int *);
extern decimal_double (frexpod)(decimal_double, /*@out@*/ int *);
extern void (gamibd)(/*@out@*/ decimal_double[/* 2 */], decimal_double, decimal_double);
extern decimal_double (gamicd)(decimal_double, decimal_double);
extern decimal_double (gamid)(decimal_double, decimal_double);
extern decimal_double (hypotd)(decimal_double, decimal_double);
extern decimal_double (ichisqd)(int, decimal_double);
extern decimal_double (ierfcd)(decimal_double);
extern decimal_double (ierfd)(decimal_double);
extern int (ilogbd)(decimal_double);
extern decimal_double (inftyd)(void);
extern int (intxpd)(decimal_double);
extern decimal_double (iphicd)(decimal_double);
extern decimal_double (iphid)(decimal_double);
extern decimal_double (ipowd)(decimal_double, int);
extern int (isfinited)(decimal_double);
extern int (isgreaterd)(decimal_double, decimal_double);
extern int (isgreaterequald)(decimal_double, decimal_double);
extern int (isinfd)(decimal_double);
extern int (islessd)(decimal_double, decimal_double);
extern int (islessequald)(decimal_double, decimal_double);
extern int (islessgreaterd)(decimal_double, decimal_double);
extern int (isnand)(decimal_double);
extern int (isnormald)(decimal_double);
extern int (isqnand)(decimal_double);
extern int (issnand)(decimal_double);
extern int (issubnormald)(decimal_double);
extern int (isunorderedd)(decimal_double, decimal_double);
extern decimal_double (j0d)(decimal_double);
extern decimal_double (j1d)(decimal_double);
extern decimal_double (jnd)(int, decimal_double);
extern decimal_double (ldexpd)(decimal_double, int);
extern decimal_double (ldexphd)(decimal_double, int);
extern decimal_double (ldexpod)(decimal_double, int);
extern decimal_double (lgammad)(decimal_double);
extern decimal_double (lgammad_r)(decimal_double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintd)(decimal_double);
extern long long int (llroundd)(decimal_double);
#endif

extern decimal_double (log101pd)(decimal_double);
extern decimal_double (log10d)(decimal_double);
extern decimal_double (log161pd)(decimal_double);
extern decimal_double (log16d)(decimal_double);
extern decimal_double (log1pd)(decimal_double);
extern decimal_double (log21pd)(decimal_double);
extern decimal_double (log2d)(decimal_double);
extern decimal_double (log81pd)(decimal_double);
extern decimal_double (log8d)(decimal_double);
extern decimal_double (logbfactd)(int, /*@out@*/ int *);
extern decimal_double (logbd)(decimal_double);
extern decimal_double (logd)(decimal_double);
extern long int (lrintd)(decimal_double);
extern long int (lroundd)(decimal_double);
extern decimal_double (mchepd)(decimal_double);
extern decimal_double (modfd)(decimal_double, /*@out@*/ decimal_double *);
extern decimal_double (nand)(const char *);
extern decimal_double (nearbyintd)(decimal_double);
extern decimal_double (nextafterd)(decimal_double, decimal_double);

#if defined(HAVE_DECIMAL_LONG_DOUBLE)

extern decimal_double (nexttowardd)(decimal_double, decimal_long_double);

#endif /* defined(HAVE_DECIMAL_LONG_DOUBLE) */

extern decimal_double (normalized)(decimal_double);
extern const char    *(ntosd)(decimal_double);
extern decimal_double (pgammad)(int, decimal_double);
extern decimal_double (phicd)(decimal_double);
extern decimal_double (phid)(decimal_double);
extern decimal_double (powd)(decimal_double, decimal_double);
extern decimal_double (psid)(decimal_double);
extern decimal_double (psilnd)(decimal_double);
extern int (qertd)(decimal_double, decimal_double, decimal_double, /*@out@*/ decimal_double [/* 2 */], /*@out@*/ decimal_double [/* 2 */]);
extern decimal_double (qnand)(const char *);
extern decimal_double (quantized)(decimal_double, decimal_double);
extern decimal_double (remainderd)(decimal_double, decimal_double);
extern decimal_double (remquod)(decimal_double, decimal_double, /*@out@*/ int *);
extern decimal_double (rintd)(decimal_double);
extern decimal_double (roundd)(decimal_double);
extern decimal_double (rsqrtd)(decimal_double);
extern int (samequantumd)(decimal_double, decimal_double);
extern decimal_double (sbi0d)(decimal_double);
extern decimal_double (sbi1d)(decimal_double);
extern decimal_double (sbind)(int, decimal_double);
extern decimal_double (sbis0d)(decimal_double);
extern decimal_double (sbis1d)(decimal_double);
extern decimal_double (sbisnd)(int, decimal_double);
extern decimal_double (sbj0d)(decimal_double);
extern decimal_double (sbj1d)(decimal_double);
extern decimal_double (sbjnd)(int, decimal_double);
extern decimal_double (sbk0d)(decimal_double);
extern decimal_double (sbk1d)(decimal_double);
extern decimal_double (sbknd)(int, decimal_double);
extern decimal_double (sbks0d)(decimal_double);
extern decimal_double (sbks1d)(decimal_double);
extern decimal_double (sbksnd)(int, decimal_double);
extern decimal_double (sby0d)(decimal_double);
extern decimal_double (sby1d)(decimal_double);
extern decimal_double (sbynd)(int, decimal_double);
extern decimal_double (scalblnd)(decimal_double, long int);
extern decimal_double (scalbnd)(decimal_double, int);
extern decimal_double (secondd)(void);
extern decimal_double (setxpd)(decimal_double, int);
extern int (signbitd)(decimal_double);
extern void (sincosd)(decimal_double, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *);
extern void (sincospd)(decimal_double, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *);
extern void (sincospid)(decimal_double, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *);
extern decimal_double (sind)(decimal_double);
extern decimal_double (sindegd)(decimal_double);
extern void (sinhcoshd)(decimal_double, /*@out@*/ decimal_double *, /*@out@*/ decimal_double *);
extern decimal_double (sinhd)(decimal_double);
extern decimal_double (sinpd)(decimal_double);
extern decimal_double (sinpid)(decimal_double);
extern decimal_double (snand)(const char *);
extern decimal_double (sqrtd)(decimal_double);
extern decimal_double (strtodd)(const char *, char **);
extern decimal_double (tand)(decimal_double);
extern decimal_double (tandegd)(decimal_double);
extern decimal_double (tanhd)(decimal_double);
extern decimal_double (tanpd)(decimal_double);
extern decimal_double (tanpid)(decimal_double);
extern decimal_double (tgammad)(decimal_double);
extern decimal_double (truncd)(decimal_double);
extern decimal_double (ulpkd)(decimal_long_double);
extern decimal_double (ulpmhd)(decimal_long_double);
extern decimal_double (vagmd)(decimal_double, decimal_double, decimal_double, int, /*@out@*/ decimal_double [], /*@out@*/ decimal_double [], /*@out@*/ decimal_double [], /*@out@*/ int *);
extern void (vbid)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vbisd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vbjd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vbkd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vbksd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vbyd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (_vcopyd)(int, /*@out@*/ decimal_double *, decimal_double *);
extern void (vsbid)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vsbisd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vsbjd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vsbkd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vsbksd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (vsbyd)(int, /*@out@*/ decimal_double *, decimal_double);
extern void (_vsetd)(int, /*@out@*/ decimal_double *, decimal_double);
extern decimal_double (vsumd)(/*@out@*/ decimal_double *, int, const decimal_double []);
extern decimal_double (y0d)(decimal_double);
extern decimal_double (y1d)(decimal_double);
extern decimal_double (ynd)(int, decimal_double);
extern decimal_double (zetad)(decimal_double);
extern decimal_double (zetam1d)(decimal_double);
extern decimal_double (zetnm1d)(int);
extern decimal_double (zetnumd)(int);

#if defined(HAVE_DECIMAL_LONG_DOUBLE)

extern decimal_long_double (acosdegdl)(decimal_long_double);
extern decimal_long_double (acosdl)(decimal_long_double);
extern decimal_long_double (acoshdl)(decimal_long_double);
extern decimal_long_double (acospdl)(decimal_long_double);
extern decimal_long_double (acospidl)(decimal_long_double);
extern decimal_long_double (adxdl)(decimal_long_double, int);
extern decimal_long_double (agmdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (annuitydl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (asindegdl)(decimal_long_double);
extern decimal_long_double (asindl)(decimal_long_double);
extern decimal_long_double (asinhdl)(decimal_long_double);
extern decimal_long_double (asinpdl)(decimal_long_double);
extern decimal_long_double (asinpidl)(decimal_long_double);
extern decimal_long_double (atan2degdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (atan2dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (atan2pdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (atan2pidl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (atandegdl)(decimal_long_double);
extern decimal_long_double (atandl)(decimal_long_double);
extern decimal_long_double (atanhdl)(decimal_long_double);
extern decimal_long_double (atanpdl)(decimal_long_double);
extern decimal_long_double (atanpidl)(decimal_long_double);
extern decimal_long_double (bernumdl)(int);
extern decimal_long_double (betadl)(decimal_long_double);
extern decimal_long_double (betam1dl)(decimal_long_double);
extern decimal_long_double (betnm1dl)(int);
extern decimal_long_double (betnumdl)(int);
extern decimal_long_double (bi0dl)(decimal_long_double);
extern decimal_long_double (bis0dl)(decimal_long_double);
extern decimal_long_double (bi1dl)(decimal_long_double);
extern decimal_long_double (bis1dl)(decimal_long_double);
extern decimal_long_double (bindl)(int, decimal_long_double);
extern decimal_long_double (binomdl)(int, int);
extern decimal_long_double (bisndl)(int, decimal_long_double);
extern decimal_long_double (bk0dl)(decimal_long_double);
extern decimal_long_double (bks0dl)(decimal_long_double);
extern decimal_long_double (bk1dl)(decimal_long_double);
extern decimal_long_double (bks1dl)(decimal_long_double);
extern decimal_long_double (bkndl)(int, decimal_long_double);
extern decimal_long_double (bksndl)(int, decimal_long_double);
extern decimal_long_double (cbrtdl)(decimal_long_double);
extern decimal_long_double (ceildl)(decimal_long_double);
extern decimal_long_double (chisqdl)(int, decimal_long_double);
extern decimal_long_double (compounddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (copysigndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (cosdegdl)(decimal_long_double);
extern decimal_long_double (cosdl)(decimal_long_double);
extern decimal_long_double (coshdl)(decimal_long_double);
extern decimal_long_double (cospdl)(decimal_long_double);
extern decimal_long_double (cospidl)(decimal_long_double);
extern decimal_long_double (cotandegdl)(decimal_long_double);
extern decimal_long_double (cotandl)(decimal_long_double);
extern decimal_long_double (cotanpdl)(decimal_long_double);
extern decimal_long_double (cotanpidl)(decimal_long_double);
extern decimal_long_double (dfactdl)(int);
extern decimal_long_double (echebdl)(decimal_long_double, int, const decimal_long_double []);
extern decimal_long_double (eljaamdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljacddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljacndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljacsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljadcdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljadndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljadsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljagdl)(decimal_long_double, decimal_long_double, int, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *, /*@out@*/ int *);
extern decimal_long_double (eljamdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljancdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljanddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljansdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljascdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljasddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljasndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljcddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljcndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljcsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljdcdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljdndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljdsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljhdl)(decimal_long_double, decimal_long_double);
extern void (eljh4dl)(/*@out@*/ decimal_long_double[], decimal_long_double, decimal_long_double);
extern decimal_long_double (eljncdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljnddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljnsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljscdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljsddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljsndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljtdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljt1dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljt2dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljt3dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljt4dl)(decimal_long_double, decimal_long_double);
extern void (eljtadl)(/*@out@*/ decimal_long_double[], decimal_long_double, decimal_long_double);
extern decimal_long_double (eljtd1dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljtd2dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljtd3dl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (eljtd4dl)(decimal_long_double, decimal_long_double);
extern void (eljtdadl)(/*@out@*/ decimal_long_double [], decimal_long_double, decimal_long_double);
extern decimal_long_double (eljzdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (elkdl)(decimal_long_double);
extern decimal_long_double (elkm1dl)(decimal_long_double);
extern decimal_long_double (elldidl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellecdl)(decimal_long_double);
extern decimal_long_double (elledl)(decimal_long_double);
extern decimal_long_double (elleidl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellfidl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellkcdl)(decimal_long_double);
extern decimal_long_double (ellkdl)(decimal_long_double);
extern decimal_long_double (ellkndl)(decimal_long_double);
extern decimal_long_double (ellpidl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrcdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrddl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellredl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrfdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrgdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrhdl)(decimal_long_double, decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrjdl)(decimal_long_double, decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrkdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrldl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ellrmdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (elntcdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (elntddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (elntndl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (elntsdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (elqdl)(decimal_long_double);
extern decimal_long_double (elq1pdl)(decimal_long_double);
extern decimal_long_double (elqcdl)(decimal_long_double);
extern decimal_long_double (elqc1pdl)(decimal_long_double);
extern decimal_long_double (elwdpdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern void (elwedl)(/*@null@*/ /*@out@*/ decimal_long_double *, /*@null@*/ /*@out@*/ decimal_long_double *, decimal_long_double, decimal_long_double);
extern void (elwgdl)(/*@null@*/ /*@out@*/ decimal_long_double *, /*@null@*/ /*@out@*/ decimal_long_double *, decimal_long_double, decimal_long_double);
extern decimal_long_double (elwipdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern void (elwkdl)(/*@null@*/ /*@out@*/ decimal_long_double *, /*@null@*/ /*@out@*/ decimal_long_double *, decimal_long_double, decimal_long_double);
extern void (elwodl)(/*@null@*/ /*@out@*/ decimal_long_double *, /*@null@*/ /*@out@*/ decimal_long_double *, decimal_long_double, decimal_long_double);
extern decimal_long_double (elwpdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (elwsdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (elwzdl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (ereducedl)(decimal_long_double, decimal_long_double, int, const decimal_long_double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_long_double *, int);
extern decimal_long_double (erfcdl)(decimal_long_double);
extern decimal_long_double (erfdl)(decimal_long_double);
extern decimal_long_double (eriducedl)(decimal_long_double, decimal_long_double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_long_double *, int);
extern decimal_long_double (eulnumdl)(int);
extern decimal_long_double (exp10dl)(decimal_long_double);
extern decimal_long_double (exp10m1dl)(decimal_long_double);
extern decimal_long_double (exp16dl)(decimal_long_double);
extern decimal_long_double (exp16m1dl)(decimal_long_double);
extern decimal_long_double (exp2dl)(decimal_long_double);
extern decimal_long_double (exp2m1dl)(decimal_long_double);
extern decimal_long_double (exp8dl)(decimal_long_double);
extern decimal_long_double (exp8m1dl)(decimal_long_double);
extern decimal_long_double (expdl)(decimal_long_double);
extern decimal_long_double (expm1dl)(decimal_long_double);
extern decimal_long_double (fabsdl)(decimal_long_double);
extern decimal_long_double (factdl)(int);
extern decimal_long_double (fdimdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (fibnumdl)(int);
extern decimal_long_double (floordl)(decimal_long_double);
extern decimal_long_double (fmadl)(decimal_long_double, decimal_long_double, decimal_long_double);
extern decimal_long_double (fmaxdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (fmindl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (fmoddl)(decimal_long_double, decimal_long_double);
extern void (fmuldl)(/*@out@*/ decimal_long_double [/* 2 */], decimal_long_double, decimal_long_double);
extern int (fpclassifydl)(decimal_long_double);
extern decimal_long_double (frexpdl)(decimal_long_double, /*@out@*/ int *);
extern decimal_long_double (frexphdl)(decimal_long_double, /*@out@*/ int *);
extern decimal_long_double (frexpodl)(decimal_long_double, /*@out@*/ int *);
extern void (gamibdl)(/*@out@*/ decimal_long_double[/* 2 */], decimal_long_double, decimal_long_double);
extern decimal_long_double (gamicdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (gamidl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (hypotdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (ichisqdl)(int, decimal_long_double);
extern decimal_long_double (ierfcdl)(decimal_long_double);
extern decimal_long_double (ierfdl)(decimal_long_double);
extern int (ilogbdl)(decimal_long_double);
extern decimal_long_double (inftydl)(void);
extern int (intxpdl)(decimal_long_double);
extern decimal_long_double (iphicdl)(decimal_long_double);
extern decimal_long_double (iphidl)(decimal_long_double);
extern decimal_long_double (ipowdl)(decimal_long_double, int);
extern int (isfinitedl)(decimal_long_double);
extern int (isgreaterdl)(decimal_long_double, decimal_long_double);
extern int (isgreaterequaldl)(decimal_long_double, decimal_long_double);
extern int (isinfdl)(decimal_long_double);
extern int (islessdl)(decimal_long_double, decimal_long_double);
extern int (islessequaldl)(decimal_long_double, decimal_long_double);
extern int (islessgreaterdl)(decimal_long_double, decimal_long_double);
extern int (isnandl)(decimal_long_double);
extern int (isnormaldl)(decimal_long_double);
extern int (isqnandl)(decimal_long_double);
extern int (issnandl)(decimal_long_double);
extern int (issubnormaldl)(decimal_long_double);
extern int (isunordereddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (j0dl)(decimal_long_double);
extern decimal_long_double (j1dl)(decimal_long_double);
extern decimal_long_double (jndl)(int, decimal_long_double);
extern decimal_long_double (ldexpdl)(decimal_long_double, int);
extern decimal_long_double (ldexphdl)(decimal_long_double, int);
extern decimal_long_double (ldexpodl)(decimal_long_double, int);
extern decimal_long_double (lgammadl)(decimal_long_double);
extern decimal_long_double (lgammadl_r)(decimal_long_double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintdl)(decimal_long_double);
extern long long int (llrounddl)(decimal_long_double);
#endif

extern decimal_long_double (log101pdl)(decimal_long_double);
extern decimal_long_double (log10dl)(decimal_long_double);
extern decimal_long_double (log161pdl)(decimal_long_double);
extern decimal_long_double (log16dl)(decimal_long_double);
extern decimal_long_double (log1pdl)(decimal_long_double);
extern decimal_long_double (log21pdl)(decimal_long_double);
extern decimal_long_double (log2dl)(decimal_long_double);
extern decimal_long_double (log81pdl)(decimal_long_double);
extern decimal_long_double (log8dl)(decimal_long_double);
extern decimal_long_double (logbfactdl)(int, /*@out@*/ int *);
extern decimal_long_double (logbdl)(decimal_long_double);
extern decimal_long_double (logdl)(decimal_long_double);
extern long int (lrintdl)(decimal_long_double);
extern long int (lrounddl)(decimal_long_double);
extern decimal_long_double (mchepdl)(decimal_long_double);
extern decimal_long_double (modfdl)(decimal_long_double, /*@out@*/ decimal_long_double *);
extern decimal_long_double (nandl)(const char *);
extern decimal_long_double (nearbyintdl)(decimal_long_double);
extern decimal_long_double (nextafterdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (nexttowarddl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (normalizedl)(decimal_long_double);
extern const char	  *(ntosdl)(decimal_long_double);
extern decimal_long_double (pgammadl)(int, decimal_long_double);
extern decimal_long_double (phicdl)(decimal_long_double);
extern decimal_long_double (phidl)(decimal_long_double);
extern decimal_long_double (powdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (psidl)(decimal_long_double);
extern decimal_long_double (psilndl)(decimal_long_double);
extern int (qertdl)(decimal_long_double, decimal_long_double, decimal_long_double, /*@out@*/ decimal_long_double [/* 2 */], /*@out@*/ decimal_long_double [/* 2 */]);
extern decimal_long_double (qnandl)(const char *);
extern decimal_long_double (quantizedl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (remainderdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (remquodl)(decimal_long_double, decimal_long_double, /*@out@*/ int *);
extern decimal_long_double (rintdl)(decimal_long_double);
extern decimal_long_double (rounddl)(decimal_long_double);
extern decimal_long_double (rsqrtdl)(decimal_long_double);
extern int (samequantumdl)(decimal_long_double, decimal_long_double);
extern decimal_long_double (sbi0dl)(decimal_long_double);
extern decimal_long_double (sbi1dl)(decimal_long_double);
extern decimal_long_double (sbindl)(int, decimal_long_double);
extern decimal_long_double (sbis0dl)(decimal_long_double);
extern decimal_long_double (sbis1dl)(decimal_long_double);
extern decimal_long_double (sbisndl)(int, decimal_long_double);
extern decimal_long_double (sbj0dl)(decimal_long_double);
extern decimal_long_double (sbj1dl)(decimal_long_double);
extern decimal_long_double (sbjndl)(int, decimal_long_double);
extern decimal_long_double (sbk0dl)(decimal_long_double);
extern decimal_long_double (sbk1dl)(decimal_long_double);
extern decimal_long_double (sbkndl)(int, decimal_long_double);
extern decimal_long_double (sbks0dl)(decimal_long_double);
extern decimal_long_double (sbks1dl)(decimal_long_double);
extern decimal_long_double (sbksndl)(int, decimal_long_double);
extern decimal_long_double (sby0dl)(decimal_long_double);
extern decimal_long_double (sby1dl)(decimal_long_double);
extern decimal_long_double (sbyndl)(int, decimal_long_double);
extern decimal_long_double (scalblndl)(decimal_long_double, long int);
extern decimal_long_double (scalbndl)(decimal_long_double, int);
extern decimal_long_double (seconddl)(void);
extern decimal_long_double (setxpdl)(decimal_long_double, int);
extern int (signbitdl)(decimal_long_double);
extern void (sincosdl)(decimal_long_double, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *);
extern void (sincospdl)(decimal_long_double, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *);
extern void (sincospidl)(decimal_long_double, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *);
extern decimal_long_double (sindegdl)(decimal_long_double);
extern decimal_long_double (sindl)(decimal_long_double);
extern void (sinhcoshdl)(decimal_long_double, /*@out@*/ decimal_long_double *, /*@out@*/ decimal_long_double *);
extern decimal_long_double (sinhdl)(decimal_long_double);
extern decimal_long_double (sinpdl)(decimal_long_double);
extern decimal_long_double (sinpidl)(decimal_long_double);
extern decimal_long_double (snandl)(const char *);
extern decimal_long_double (sqrtdl)(decimal_long_double);
extern decimal_long_double (strtoddl)(const char *, char **);
extern decimal_long_double (tandegdl)(decimal_long_double);
extern decimal_long_double (tandl)(decimal_long_double);
extern decimal_long_double (tanhdl)(decimal_long_double);
extern decimal_long_double (tanpdl)(decimal_long_double);
extern decimal_long_double (tanpidl)(decimal_long_double);
extern decimal_long_double (tgammadl)(decimal_long_double);
extern decimal_long_double (truncdl)(decimal_long_double);
extern decimal_long_double (ulpkdl)(decimal_long_long_double);
extern decimal_long_double (ulpmhdl)(decimal_long_long_double);
extern decimal_long_double (vagmdl)(decimal_long_double, decimal_long_double, decimal_long_double, int, /*@out@*/ decimal_long_double [], /*@out@*/ decimal_long_double [], /*@out@*/ decimal_long_double [], /*@out@*/ int *);
extern void (vbidl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vbisdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vbjdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vbkdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vbksdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vbydl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (_vcopydl)(int, /*@out@*/ decimal_long_double *, decimal_long_double *);
extern void (vsbidl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vsbisdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vsbjdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vsbkdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vsbksdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (vsbydl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern void (_vsetdl)(int, /*@out@*/ decimal_long_double *, decimal_long_double);
extern decimal_long_double (vsumdl)(/*@out@*/ decimal_long_double *, int, const decimal_long_double []);
extern decimal_long_double (y0dl)(decimal_long_double);
extern decimal_long_double (y1dl)(decimal_long_double);
extern decimal_long_double (yndl)(int, decimal_long_double);
extern decimal_long_double (zetadl)(decimal_long_double);
extern decimal_long_double (zetam1dl)(decimal_long_double);
extern decimal_long_double (zetnm1dl)(int);
extern decimal_long_double (zetnumdl)(int);

#endif /* defined(HAVE_DECIMAL_LONG_DOUBLE) */

#if defined(HAVE_DECIMAL_LONG_LONG_DOUBLE)

extern decimal_long_long_double (acosdegdll)(decimal_long_long_double);
extern decimal_long_long_double (acosdll)(decimal_long_long_double);
extern decimal_long_long_double (acoshdll)(decimal_long_long_double);
extern decimal_long_long_double (acospdll)(decimal_long_long_double);
extern decimal_long_long_double (acospidll)(decimal_long_long_double);
extern decimal_long_long_double (adxdll)(decimal_long_long_double, int);
extern decimal_long_long_double (agmdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (annuitydll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (asindegdll)(decimal_long_long_double);
extern decimal_long_long_double (asindll)(decimal_long_long_double);
extern decimal_long_long_double (asinhdll)(decimal_long_long_double);
extern decimal_long_long_double (asinpdll)(decimal_long_long_double);
extern decimal_long_long_double (asinpidll)(decimal_long_long_double);
extern decimal_long_long_double (atan2degdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (atan2dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (atan2pdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (atan2pidll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (atandegdll)(decimal_long_long_double);
extern decimal_long_long_double (atandll)(decimal_long_long_double);
extern decimal_long_long_double (atanhdll)(decimal_long_long_double);
extern decimal_long_long_double (atanpdll)(decimal_long_long_double);
extern decimal_long_long_double (atanpidll)(decimal_long_long_double);
extern decimal_long_long_double (bernumdll)(int);
extern decimal_long_long_double (betadll)(decimal_long_long_double);
extern decimal_long_long_double (betam1dll)(decimal_long_long_double);
extern decimal_long_long_double (betnm1dll)(int);
extern decimal_long_long_double (betnumdll)(int);
extern decimal_long_long_double (bi0dll)(decimal_long_long_double);
extern decimal_long_long_double (bis0dll)(decimal_long_long_double);
extern decimal_long_long_double (bi1dll)(decimal_long_long_double);
extern decimal_long_long_double (bis1dll)(decimal_long_long_double);
extern decimal_long_long_double (bindll)(int, decimal_long_long_double);
extern decimal_long_long_double (binomdll)(int, int);
extern decimal_long_long_double (bisndll)(int, decimal_long_long_double);
extern decimal_long_long_double (bk0dll)(decimal_long_long_double);
extern decimal_long_long_double (bks0dll)(decimal_long_long_double);
extern decimal_long_long_double (bk1dll)(decimal_long_long_double);
extern decimal_long_long_double (bks1dll)(decimal_long_long_double);
extern decimal_long_long_double (bkndll)(int, decimal_long_long_double);
extern decimal_long_long_double (bksndll)(int, decimal_long_long_double);
extern decimal_long_long_double (cbrtdll)(decimal_long_long_double);
extern decimal_long_long_double (ceildll)(decimal_long_long_double);
extern decimal_long_long_double (chisqdll)(int, decimal_long_long_double);
extern decimal_long_long_double (compounddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (copysigndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (cosdegdll)(decimal_long_long_double);
extern decimal_long_long_double (cosdll)(decimal_long_long_double);
extern decimal_long_long_double (coshdll)(decimal_long_long_double);
extern decimal_long_long_double (cospdll)(decimal_long_long_double);
extern decimal_long_long_double (cospidll)(decimal_long_long_double);
extern decimal_long_long_double (cotandegdll)(decimal_long_long_double);
extern decimal_long_long_double (cotandll)(decimal_long_long_double);
extern decimal_long_long_double (cotanpdll)(decimal_long_long_double);
extern decimal_long_long_double (cotanpidll)(decimal_long_long_double);
extern decimal_long_long_double (dfactdll)(int);
extern decimal_long_long_double (echebdll)(decimal_long_long_double, int, const decimal_long_long_double []);
extern decimal_long_long_double (eljaamdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljacddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljacndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljacsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljadcdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljadndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljadsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljagdll)(decimal_long_long_double, decimal_long_long_double, int, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *, /*@out@*/ int *);
extern decimal_long_long_double (eljamdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljancdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljanddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljansdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljascdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljasddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljasndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljcddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljcndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljcsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljdcdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljdndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljdsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljhdll)(decimal_long_long_double, decimal_long_long_double);
extern void (eljh4dll)(/*@out@*/ decimal_long_long_double[], decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljncdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljnddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljnsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljscdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljsddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljsndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljtdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljt1dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljt2dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljt3dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljt4dll)(decimal_long_long_double, decimal_long_long_double);
extern void (eljtadll)(/*@out@*/ decimal_long_long_double[], decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljtd1dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljtd2dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljtd3dll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljtd4dll)(decimal_long_long_double, decimal_long_long_double);
extern void (eljtdadll)(/*@out@*/ decimal_long_long_double [], decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (eljzdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elkdll)(decimal_long_long_double);
extern decimal_long_long_double (elkm1dll)(decimal_long_long_double);
extern decimal_long_long_double (elldidll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellecdll)(decimal_long_long_double);
extern decimal_long_long_double (elledll)(decimal_long_long_double);
extern decimal_long_long_double (elleidll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellfidll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellkcdll)(decimal_long_long_double);
extern decimal_long_long_double (ellkdll)(decimal_long_long_double);
extern decimal_long_long_double (ellkndll)(decimal_long_long_double);
extern decimal_long_long_double (ellpidll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrcdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrddll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellredll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrfdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrgdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrhdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrjdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrkdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrldll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ellrmdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elntcdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elntddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elntndll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elntsdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elqdll)(decimal_long_long_double);
extern decimal_long_long_double (elq1pdll)(decimal_long_long_double);
extern decimal_long_long_double (elqcdll)(decimal_long_long_double);
extern decimal_long_long_double (elqc1pdll)(decimal_long_long_double);
extern decimal_long_long_double (elwdpdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern void (elwedll)(/*@null@*/ /*@out@*/ decimal_long_long_double *, /*@null@*/ /*@out@*/ decimal_long_long_double *, decimal_long_long_double, decimal_long_long_double);
extern void (elwgdll)(/*@null@*/ /*@out@*/ decimal_long_long_double *, /*@null@*/ /*@out@*/ decimal_long_long_double *, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elwipdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern void (elwkdll)(/*@null@*/ /*@out@*/ decimal_long_long_double *, /*@null@*/ /*@out@*/ decimal_long_long_double *, decimal_long_long_double, decimal_long_long_double);
extern void (elwodll)(/*@null@*/ /*@out@*/ decimal_long_long_double *, /*@null@*/ /*@out@*/ decimal_long_long_double *, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elwpdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elwsdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (elwzdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ereducedll)(decimal_long_long_double, decimal_long_long_double, int, const decimal_long_long_double [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_long_long_double *, int);
extern decimal_long_long_double (erfcdll)(decimal_long_long_double);
extern decimal_long_long_double (erfdll)(decimal_long_long_double);
extern decimal_long_long_double (eriducedll)(decimal_long_long_double, decimal_long_long_double, int, const int [], /*@null@*/ /*@out@*/ int *, /*@null@*/ /*@out@*/ decimal_long_long_double *, int);
extern decimal_long_long_double (eulnumdll)(int);
extern decimal_long_long_double (exp10dll)(decimal_long_long_double);
extern decimal_long_long_double (exp10m1dll)(decimal_long_long_double);
extern decimal_long_long_double (exp16dll)(decimal_long_long_double);
extern decimal_long_long_double (exp16m1dll)(decimal_long_long_double);
extern decimal_long_long_double (exp2dll)(decimal_long_long_double);
extern decimal_long_long_double (exp2m1dll)(decimal_long_long_double);
extern decimal_long_long_double (exp8dll)(decimal_long_long_double);
extern decimal_long_long_double (exp8m1dll)(decimal_long_long_double);
extern decimal_long_long_double (expdll)(decimal_long_long_double);
extern decimal_long_long_double (expm1dll)(decimal_long_long_double);
extern decimal_long_long_double (fabsdll)(decimal_long_long_double);
extern decimal_long_long_double (factdll)(int);
extern decimal_long_long_double (fdimdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (fibnumdll)(int);
extern decimal_long_long_double (floordll)(decimal_long_long_double);
extern decimal_long_long_double (fmadll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (fmaxdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (fmindll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (fmoddll)(decimal_long_long_double, decimal_long_long_double);
extern void (fmuldll)(/*@out@*/ decimal_long_long_double [/* 2 */], decimal_long_long_double, decimal_long_long_double);
extern int (fpclassifydll)(decimal_long_long_double);
extern decimal_long_long_double (frexpdll)(decimal_long_long_double, /*@out@*/ int *);
extern decimal_long_long_double (frexphdll)(decimal_long_long_double, /*@out@*/ int *);
extern decimal_long_long_double (frexpodll)(decimal_long_long_double, /*@out@*/ int *);
extern void (gamibdll)(/*@out@*/ decimal_long_long_double[/* 2 */], decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (gamicdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (gamidll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (hypotdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (ichisqdll)(int, decimal_long_long_double);
extern decimal_long_long_double (ierfcdll)(decimal_long_long_double);
extern decimal_long_long_double (ierfdll)(decimal_long_long_double);
extern int (ilogbdll)(decimal_long_long_double);
extern decimal_long_long_double (inftydll)(void);
extern int (intxpdll)(decimal_long_long_double);
extern decimal_long_long_double (iphicdll)(decimal_long_long_double);
extern decimal_long_long_double (iphidll)(decimal_long_long_double);
extern decimal_long_long_double (ipowdll)(decimal_long_long_double, int);
extern int (isfinitedll)(decimal_long_long_double);
extern int (isgreaterdll)(decimal_long_long_double, decimal_long_long_double);
extern int (isgreaterequaldll)(decimal_long_long_double, decimal_long_long_double);
extern int (isinfdll)(decimal_long_long_double);
extern int (islessdll)(decimal_long_long_double, decimal_long_long_double);
extern int (islessequaldll)(decimal_long_long_double, decimal_long_long_double);
extern int (islessgreaterdll)(decimal_long_long_double, decimal_long_long_double);
extern int (isnandll)(decimal_long_long_double);
extern int (isnormaldll)(decimal_long_long_double);
extern int (isqnandll)(decimal_long_long_double);
extern int (issnandll)(decimal_long_long_double);
extern int (issubnormaldll)(decimal_long_long_double);
extern int (isunordereddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (j0dll)(decimal_long_long_double);
extern decimal_long_long_double (j1dll)(decimal_long_long_double);
extern decimal_long_long_double (jndll)(int, decimal_long_long_double);
extern decimal_long_long_double (ldexpdll)(decimal_long_long_double, int);
extern decimal_long_long_double (ldexphdll)(decimal_long_long_double, int);
extern decimal_long_long_double (ldexpodll)(decimal_long_long_double, int);
extern decimal_long_long_double (lgammadll)(decimal_long_long_double);
extern decimal_long_long_double (lgammadll_r)(decimal_long_long_double, /*@out@*/ int *);

#if defined(HAVE_LONG_LONG_INT)
extern long long int (llrintdll)(decimal_long_long_double);
extern long long int (llrounddll)(decimal_long_long_double);
#endif

extern decimal_long_long_double (log101pdll)(decimal_long_long_double);
extern decimal_long_long_double (log10dll)(decimal_long_long_double);
extern decimal_long_long_double (log161pdll)(decimal_long_long_double);
extern decimal_long_long_double (log16dll)(decimal_long_long_double);
extern decimal_long_long_double (log1pdll)(decimal_long_long_double);
extern decimal_long_long_double (log21pdll)(decimal_long_long_double);
extern decimal_long_long_double (log2dll)(decimal_long_long_double);
extern decimal_long_long_double (log81pdll)(decimal_long_long_double);
extern decimal_long_long_double (log8dll)(decimal_long_long_double);
extern decimal_long_long_double (logbfactdll)(int, /*@out@*/ int *);
extern decimal_long_long_double (logbdll)(decimal_long_long_double);
extern decimal_long_long_double (logdll)(decimal_long_long_double);
extern long int (lrintdll)(decimal_long_long_double);
extern long int (lrounddll)(decimal_long_long_double);
extern decimal_long_long_double (mchepdll)(decimal_long_long_double);
extern decimal_long_long_double (modfdll)(decimal_long_long_double, /*@out@*/ decimal_long_long_double *);
extern decimal_long_long_double (nandll)(const char *);
extern decimal_long_long_double (nearbyintdll)(decimal_long_long_double);
extern decimal_long_long_double (nextafterdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (nexttowarddll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (normalizedll)(decimal_long_long_double);
extern const char		*(ntosdll)(decimal_long_long_double);
extern decimal_long_long_double (pgammadll)(int, decimal_long_long_double);
extern decimal_long_long_double (phicdll)(decimal_long_long_double);
extern decimal_long_long_double (phidll)(decimal_long_long_double);
extern decimal_long_long_double (powdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (psidll)(decimal_long_long_double);
extern decimal_long_long_double (psilndll)(decimal_long_long_double);
extern int (qertdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double, /*@out@*/ decimal_long_long_double [/* 2 */], /*@out@*/ decimal_long_long_double [/* 2 */]);
extern decimal_long_long_double (qnandll)(const char *);
extern decimal_long_long_double (quantizedll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (remainderdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (remquodll)(decimal_long_long_double, decimal_long_long_double, /*@out@*/ int *);
extern decimal_long_long_double (rintdll)(decimal_long_long_double);
extern decimal_long_long_double (rounddll)(decimal_long_long_double);
extern decimal_long_long_double (rsqrtdll)(decimal_long_long_double);
extern int (samequantumdll)(decimal_long_long_double, decimal_long_long_double);
extern decimal_long_long_double (sbi0dll)(decimal_long_long_double);
extern decimal_long_long_double (sbi1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbindll)(int, decimal_long_long_double);
extern decimal_long_long_double (sbis0dll)(decimal_long_long_double);
extern decimal_long_long_double (sbis1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbisndll)(int, decimal_long_long_double);
extern decimal_long_long_double (sbj0dll)(decimal_long_long_double);
extern decimal_long_long_double (sbj1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbjndll)(int, decimal_long_long_double);
extern decimal_long_long_double (sbk0dll)(decimal_long_long_double);
extern decimal_long_long_double (sbk1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbkndll)(int, decimal_long_long_double);
extern decimal_long_long_double (sbks0dll)(decimal_long_long_double);
extern decimal_long_long_double (sbks1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbksndll)(int, decimal_long_long_double);
extern decimal_long_long_double (sby0dll)(decimal_long_long_double);
extern decimal_long_long_double (sby1dll)(decimal_long_long_double);
extern decimal_long_long_double (sbyndll)(int, decimal_long_long_double);
extern decimal_long_long_double (scalblndll)(decimal_long_long_double, long int);
extern decimal_long_long_double (scalbndll)(decimal_long_long_double, int);
extern decimal_long_long_double (seconddll)(void);
extern decimal_long_long_double (setxpdll)(decimal_long_long_double, int);
extern int (signbitdll)(decimal_long_long_double);
extern void (sincosdll)(decimal_long_long_double, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *);
extern void (sincospdll)(decimal_long_long_double, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *);
extern void (sincospidll)(decimal_long_long_double, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *);
extern decimal_long_long_double (sindegdll)(decimal_long_long_double);
extern decimal_long_long_double (sindll)(decimal_long_long_double);
extern void (sinhcoshdll)(decimal_long_long_double, /*@out@*/ decimal_long_long_double *, /*@out@*/ decimal_long_long_double *);
extern decimal_long_long_double (sinhdll)(decimal_long_long_double);
extern decimal_long_long_double (sinpdll)(decimal_long_long_double);
extern decimal_long_long_double (sinpidll)(decimal_long_long_double);
extern decimal_long_long_double (snandll)(const char *);
extern decimal_long_long_double (sqrtdll)(decimal_long_long_double);
extern decimal_long_long_double (strtoddll)(const char *, char **);
extern decimal_long_long_double (tandegdll)(decimal_long_long_double);
extern decimal_long_long_double (tandll)(decimal_long_long_double);
extern decimal_long_long_double (tanhdll)(decimal_long_long_double);
extern decimal_long_long_double (tanpdll)(decimal_long_long_double);
extern decimal_long_long_double (tanpidll)(decimal_long_long_double);
extern decimal_long_long_double (tgammadll)(decimal_long_long_double);
extern decimal_long_long_double (truncdll)(decimal_long_long_double);
extern decimal_long_long_double (ulpkdll)(decimal_long_long_double);
extern decimal_long_long_double (ulpmhdll)(decimal_long_long_double);
extern decimal_long_long_double (vagmdll)(decimal_long_long_double, decimal_long_long_double, decimal_long_long_double, int, /*@out@*/ decimal_long_long_double [], /*@out@*/ decimal_long_long_double [], /*@out@*/ decimal_long_long_double [], /*@out@*/ int *);
extern void (vbidll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vbisdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vbjdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vbkdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vbksdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vbydll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (_vcopydll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double *);
extern void (vsbidll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vsbisdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vsbjdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vsbkdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vsbksdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (vsbydll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern void (_vsetdll)(int, /*@out@*/ decimal_long_long_double *, decimal_long_long_double);
extern decimal_long_long_double (vsumdll)(/*@out@*/ decimal_long_long_double *, int, const decimal_long_long_double []);
extern decimal_long_long_double (y0dll)(decimal_long_long_double);
extern decimal_long_long_double (y1dll)(decimal_long_long_double);
extern decimal_long_long_double (yndll)(int, decimal_long_long_double);
extern decimal_long_long_double (zetadll)(decimal_long_long_double);
extern decimal_long_long_double (zetam1dll)(decimal_long_long_double);
extern decimal_long_long_double (zetnm1dll)(int);
extern decimal_long_long_double (zetnumdll)(int);

#endif /* defined(HAVE_DECIMAL_LONG_LONG_DOUBLE) */

#endif /* defined(HAVE_DECIMAL) */

#if defined(__cplusplus)
}
#endif

#undef  FP_INFINITE
#undef  FP_NAN
#undef  FP_NORMAL
#undef  FP_SUBNORMAL
#undef  FP_ZERO

#define FP_INFINITE     3
#define FP_NAN          4
#define FP_NORMAL       2
#define FP_SUBNORMAL    1
#define FP_ZERO         0

#if !defined(HIDE_MATHCW_GENERICS)

/* FIXME: What needs to be done to make these C99 macros work for HP
   extended and quad types? */

/* C99-like macros: the isxxx() test macros are type-generic, but
   compile-time tests with sizeof() turn them into type-specific
   function calls */

#undef	isfinite
#undef	isinf
#undef	isnan
#undef	isnormal
#undef	isqnan
#undef	issnan
#undef	issubnormal
#undef	signbit

#undef	isgreater
#undef	isgreaterequal
#undef	isless
#undef	islessequal
#undef	islessgreater
#undef	isunordered

#if defined(HAVE_SHORT_NAMES)
#define isfinite(x) ((sizeof(x) == sizeof(float))  ? ((_isfif)(x)) : \
		     (sizeof(x) == sizeof(double)) ? ((_isfi)(x)) : \
		                                      (_isfil)(x))

#define isinf(x) ((sizeof(x) == sizeof(float))  ? ((isinff)(x)) : \
		  (sizeof(x) == sizeof(double)) ? ((isinf)(x)) : \
		                                   (isinfl)(x))

#define isnan(x) ((sizeof(x) == sizeof(float))  ? ((isnanf)(x)) : \
		  (sizeof(x) == sizeof(double)) ? ((isnan)(x)) : \
		  				   (isnanl)(x))

#define isnormal(x) ((sizeof(x) == sizeof(float))  ? ((_isnof)(x)) : \
		     (sizeof(x) == sizeof(double)) ? ((_isno)(x)) : \
		                                      (_isnol)(x))

/* isqnan() is curiously omitted from C99, but really ought to be there */
#define isqnan(x) ((sizeof(x) == sizeof(float))  ? ((_isqnf)(x)) : \
		   (sizeof(x) == sizeof(double)) ? ((_isqn)(x)) : \
		                                    (_isqnl)(x))

/* issnan() is curiously omitted from C99, but really ought to be there */
#define issnan(x) ((sizeof(x) == sizeof(float))  ? ((_isqnf)(x)) : \
		   (sizeof(x) == sizeof(double)) ? ((_isqn)(x)) : \
		                                    (_isqnl)(x))

/* issubnormal() is curiously omitted from C99, but really ought to be there */
#define issubnormal(x) ((sizeof(x) == sizeof(float))  ? ((_issuf)(x)) : \
		        (sizeof(x) == sizeof(double)) ? ((_issu)(x)) : \
		                                         (_issul)(x))

#define signbit(x) ((sizeof(x) == sizeof(float))  ? (_sgnbf)(x)) : \
		    (sizeof(x) == sizeof(double)) ? (_sgnb)(x)) : \
		                                     _sgnbl)(x))

#define isgreater(x,y) ((sizeof(x) == sizeof(float))  ? ((_isgtf)((x),(y))) : \
	    	        (sizeof(x) == sizeof(double)) ? ((_isgt)((x),(y))) : \
		                                         (_isgtl)((x),(y)))

#define isgreaterequal(x,y) ((sizeof(x) == sizeof(float))  ? ((_isgef)((x),(y))) : \
		    	     (sizeof(x) == sizeof(double)) ? ((_isge)((x),(y))) : \
		                                              (_isgel)((x),(y)))

#define isless(x,y) ((sizeof(x) == sizeof(float))  ? ((_isltf)((x),(y))) : \
	    	     (sizeof(x) == sizeof(double)) ? ((_islt)((x),(y))) : \
		                                      (_isltl)((x),(y)))

#define islessequal(x,y) ((sizeof(x) == sizeof(float))  ? ((_islef)((x),(y))) : \
		    	     (sizeof(x) == sizeof(double)) ? ((_isle)((x),(y))) : \
		                                              (_islel)((x),(y)))

#define islessgreater(x,y) ((sizeof(x) == sizeof(float))  ? ((_islgf)((x),(y))) : \
		    	    (sizeof(x) == sizeof(double)) ? ((_islg)((x),(y))) : \
		                                             (_islgl)((x),(y)))

#define isunordered(x,y) ((sizeof(x) == sizeof(float))  ? ((_isunf)((x),(y))) : \
	    	          (sizeof(x) == sizeof(double)) ? ((_isun)((x),(y))) : \
		                                           (_isunl)((x),(y)))

#else  /* NOT defined(HAVE_SHORT_NAMES) */

#define isfinite(x) ((sizeof(x) == sizeof(float))  ? ((isfinitef)(x)) : \
		     (sizeof(x) == sizeof(double)) ? ((isfinite)(x)) : \
		                                      (isfinitel)(x))

#define isinf(x) ((sizeof(x) == sizeof(float))  ? ((isinff)(x)) : \
		  (sizeof(x) == sizeof(double)) ? ((isinf)(x)) : \
		                                   (isinfl)(x))

#define isnan(x) ((sizeof(x) == sizeof(float))  ? ((isnanf)(x)) : \
		  (sizeof(x) == sizeof(double)) ? ((isnan)(x)) : \
		                                   (isnanl)(x))

#define isnormal(x) ((sizeof(x) == sizeof(float))  ? ((isnormalf)(x)) : \
		     (sizeof(x) == sizeof(double)) ? ((isnormal)(x)) : \
		                                      (isnormall)(x))

/* isqnan() is curiously omitted from C99, but really ought to be there */
#define isqnan(x) ((sizeof(x) == sizeof(float))  ? ((isqnanf)(x)) : \
		   (sizeof(x) == sizeof(double)) ? ((isqnan)(x)) : \
		                                    (isqnanl)(x))

/* issnan() is curiously omitted from C99, but really ought to be there */
#define issnan(x) ((sizeof(x) == sizeof(float))  ? ((issnanf)(x)) : \
		   (sizeof(x) == sizeof(double)) ? ((issnan)(x)) : \
		                                    (issnanl)(x))

/* issubnormal() is curiously omitted from C99, but really ought to be there */
#define issubnormal(x) ((sizeof(x) == sizeof(float))  ? ((issubnormalf)(x)) : \
		        (sizeof(x) == sizeof(double)) ? ((issubnormal)(x)) : \
		                                           (issubnormall)(x))

#define samequantum(x,y) ((sizeof(x) == sizeof(float))  ? ((samequantumf)(x,y)) : \
		          (sizeof(x) == sizeof(double)) ? ((samequantum)(x,y)) : \
		                                           (samequantuml)(x,y))

#define signbit(x) ((sizeof(x) == sizeof(float))  ? ((signbitf)(x)) : \
		    (sizeof(x) == sizeof(double)) ? ((signbit)(x)) : \
		                                     (signbitl)(x))

#define isgreater(x,y) ((sizeof(x) == sizeof(float))  ? ((isgreaterf)((x),(y))) : \
	    	        (sizeof(x) == sizeof(double)) ? ((isgreater)((x),(y))) : \
		                                         (isgreaterl)((x),(y)))

#define isgreaterequal(x,y) ((sizeof(x) == sizeof(float))  ? ((isgreaterequalf)((x),(y))) : \
		    	     (sizeof(x) == sizeof(double)) ? ((isgreaterequal)((x),(y))) : \
		                                              (isgreaterequall)((x),(y)))

#define isless(x,y) ((sizeof(x) == sizeof(float))  ? ((islessf)((x),(y))) : \
	    	     (sizeof(x) == sizeof(double)) ? ((isless)((x),(y))) : \
		                                      (islessl)((x),(y)))

#define islessequal(x,y) ((sizeof(x) == sizeof(float))  ? ((islessequalf)((x),(y))) : \
		    	     (sizeof(x) == sizeof(double)) ? ((islessequal)((x),(y))) : \
		                                              (islessequall)((x),(y)))

#define islessgreater(x,y) ((sizeof(x) == sizeof(float))  ? ((islessgreaterf)((x),(y))) : \
		    	    (sizeof(x) == sizeof(double)) ? ((islessgreater)((x),(y))) : \
		                                             (islessgreaterl)((x),(y)))

#define isunordered(x,y) ((sizeof(x) == sizeof(float))  ? ((isunorderedf)((x),(y))) : \
	    	          (sizeof(x) == sizeof(double)) ? ((isunordered)((x),(y))) : \
		                                           (isunorderedl)((x),(y)))

#endif /* defined(HAVE_SHORT_NAMES) */

#endif /* !defined(HIDE_MATHCW_GENERICS) */

#endif /* !defined(MATHCW_H) */
